/**
 * @module barcode
 * @description QR Code类 barcode
 * @requireJS ["cmp-barcode.js"]
 */
;(function(_){
    //=======================================================================二维码组件 start========================//
    _.barcode = {};
    /**
     * @method scan
     * @platform m3
     * @createDate 2015-04-06
     * @lastModify 2017-06-21
     * @description 二维码扫描（扫描后获取结果后，自动关闭扫描）
     * @param {object} options 配置信息
     * @param {function} options.success 成功回调
     * @paramTemplate options.success arguments[0]返回的为扫描结果
     * @param {function} options.fail 失败回调
     * @param {bool} options.nativeHandleSpecialResult 默认false， 是否有原生处理特殊扫描结果（如致信群二维码）
     * @hasDemo
     */
    _.barcode.scan = function (options) {

        var _options = {
            success: null,
            error: null,
            nativeHandleSpecialResult:false
        };

        _.options = _.extend(_options, options);

        cordova.exec(
            _options.success,
            _options.error,
            "CDVBarcodeScanner",
            "scan",
            [{
                nativeHandleSpecialResult:_options.nativeHandleSpecialResult
            }]
        );
    };

    
    /**
     * @method holdScan
     * @platform m3
     * @createDate 2015-04-06
     * @lastModify 2017-06-21
     * @description 二维码扫描（获取结果后持续扫描）
     * @param {object} options 配置信息
     * @param {function} options.success 成功回调
     * @paramTemplate options.success arguments[0]返回的为扫描结果
     * @param {function} options.fail 失败回调
     * @param {bool} options.nativeHandleSpecialResult 默认false， 是否有原生处理特殊扫描结果（如致信群二维码）
     * @hasDemo
     */
    _.barcode.holdScan = function(options){
        var _options = {
            success:null,
            error:null,
            nativeHandleSpecialResult:false
        };
        _options = _.extend(_options, options);
        var callbackObj = {
            sendResult:_.barcode.holdScan.prototype.sendResult,
            close:_.barcode.holdScan.prototype.close
        };
        var success = _options.success;
        var error = _options.error;
        var successFun = function(result){
            if(success && typeof success == "function"){
                success.call(this,result,callbackObj);
            }
        };
        var errorFun = function(result){
            if(error && typeof error == "function"){
                error.call(this,result,callbackObj);
            }
        };
        cordova.exec(
            successFun,
            errorFun,
            "CDVBarcodeScanner",
            "holdScan",
            [{
                nativeHandleSpecialResult:_options.nativeHandleSpecialResult
            }]
        );
    };
    /**
     * scan2组件的保持，不关闭
     * @param val，开发者回传值
     */
    _.barcode.holdScan.prototype.sendResult = function(val){
        var callbackVal = val || null;
        cordova.exec(
            function success(){},
            function error(){},
            "CDVBarcodeScanner",
            "holdScanSendResult",
            [
                {
                    callbackVal:callbackVal
                }
            ]
        );
    };
    /**
     * scan2组件的关闭
     * @param val，开发者回传值
     */
    _.barcode.holdScan.prototype.close = function(val){
        var callbackVal = val || null;
        cordova.exec(
            function success(){},
            function error(){},
            "CDVBarcodeScanner",
            "holdScanClose",
            [
                {
                    callbackVal:callbackVal
                }
            ]
        );
    };



    /**
     * @method holdScan.notify
     * @platform m3
     * @createDate 2015-04-06
     * @lastModify 2017-06-21
     * @description 在原生的二维码界面之上弹出原生提示框
     * @param {string} val 提示的字符串
     */
    _.barcode.holdScan.notify = function(val){
        var callbackVal = val || null;
        cordova.exec(
            function success(){},
            function error(){},
            "CDVBarcodeScanner",
            "holdScanSendResult",
            [
                {
                    callbackVal:callbackVal
                }
            ]
        );
    };
    
    /**
     * @method holdScan.closeScan
     * @platform m3
     * @createDate 2015-04-06
     * @lastModify 2017-06-21
     * @description 关闭二维码扫描
     */
    _.barcode.holdScan.closeScan = function(val){
        var callbackVal = val || null;
        cordova.exec(
            function success(){},
            function error(){},
            "CDVBarcodeScanner",
            "holdScanClose",
            [
                {
                    callbackVal:callbackVal
                }
            ]
        );
    };
    /**
     * 制作二维码
     * @class makeBarScan
     * @namespace cmp
     * @param options {object} 配置项参数
     * @param {String} options.data 被用于制作二维码的字符串数据
     */
    _.barcode.makeBarScan = function (options) {
        var _options = {
            data: '',
            success: null,
            error: null
        };

        _.options = _.extend(_options, options);

        cordova.exec(
            _options.success,
            _options.error,
            "CDVBarcodeScanner",
            "encode",
            [
                {
                    "data": _options.data
                }
            ]
        );
    }
    //=======================================================================二维码组件 end========================//
})(cmp);