/**
 * @module contentEdit
 * @description 文档类 contentEdit
 * @requireJS ["cmp-contentEdit.js"]
 */
;(function(_){
    _.contentEdit = {};
    /**
     * @method open
     * @createDate 2017-05-03
     * @lastModify 2019-06-21
     * @platform m3
     * @description 打开正文
     * @param {object} options 配置对象
     * @param {string} options.filename 文件名称
     * @param {string} options.fileType 文件类型
     * @param {string} options.path 文件路径
     * @param {object} options.extData 拓展参数，详见demo
     * @param {function} options.success 成功回调 <isNotNull>
     * @param {function} options.error 失败回调 <isNotNull>
     * @hasDemo
     */
    _.contentEdit.open = function(options){
        var _options = {
            copyRight:null,//金格授权码
            filename:null,//文件名
            fileType:null,//文件类型，如doc
            path:null,//文件下载路径
            headers: cmp.util.extend(cmp.getGlobalHeader(), options.headers || {}),
            extData:{
                fileId:null,//文件id  用于储存在数据库用
                lastModified:null,//文件lastModified
                origin: _.origin//域名
            },
            success: null,//成功回调
            error: null//失败回调
        };
        _options = _.extend(_options, options);
		var action = "openDocument";
		// if(/pdf/i.test(_options.fileType)){
		// 	action = "openPDF";
		// }
        cordova.exec(
            _options.success,
            _options.error,
            "OfficePlugin",
            action,
            [
                {
                    //这个参数已经被废弃
                    "headers": _options.headers,
                    "copyRight": _options.copyRight,
                    "filename": _options.filename,
                    "fileType":_options.fileType,
                    "path":_options.path,
                    "extData": _options.extData
                }
            ]
        );
    };

    //这个API没有检索到没有使用
    _.contentEdit.close = function(options){
        var _options = {
            success:function(filepath){//返回保存后的手机本地路径
                options.success && typeof options.success == "function" && options.success.call(this,filepath);
            },
            error:options.error
        }
        cordova.exec(
            _options.success,
            _options.error,
            "OfficePlugin",
            "closeDocument",
            [{}]
        );
    };
    /**
     * @method clear
     * @createDate 2017-06-03
     * @lastModify 2019-06-21
     * @platform m3
     * @description 清空正文
     * @param {object} options 配置对象
     * @param {string} options.fileId 文件ID
     * @param {string} options.lastModified 更新时间
     * @param {function} options.success 成功回调 <isNotNull>
     * @param {function} options.error 失败回调 <isNotNull>
     * @hasDemo
     */
    _.contentEdit.clear = function(options){
        var _options = {
            fileId:"",//文件id
            lastModified:"",//文件lastModify
            success:null,
            error:null
        };
        _options = _.extend(_options, options);
        cordova.exec(
            _options.success,
            _options.error,
            "OfficePlugin",
            "clearDocument",
            [{
                fileId:_options.fileId,
                lastModified:_options.lastModified
            }]
        );
    }
})(cmp);