/*
 * 单独的日历组件
 *mashan  V7.1SP1
 */

 /**
 * @module cmp
 */
 /**
 * @method dateCalender
 * @requireJS ["cmp-dateCalender.js","cmp-dateCalender.css"]
 * @description 单独的日历组件(不是弹出类,是直接显示到你传递的容器里面去) cmp.DateCalender(el,options)
 * @createDate 2019-07-30
 * @lastModify 2019-08-14
 * @param {string} el 容器id或者类名
 * @param {object} options 配置  <isNotNull>
 * @param {string} options.type 类型 1.week：周视图 2.month月视图 <isNotNull>
 * @param {string} options.y 默认年份  <isNotNull>
 * @param {string} options.m 默认月份 <isNotNull>
 * @param {string} options.d 默认日 <isNotNull>
 * @param {string} options.value 时间默认值 格式："2018-5-5";  <isNotNull>
 * @param {string} options.beginYear 自定义开始年份  <isNotNull>
 * @param {string} options.endYear 自定义结束年份  <isNotNull>
 * @param {boolean} options.switchMothBtn 是否显示快速切换年/月视图前进后退按钮  <isNotNull>
 * @param {boolean} options.switchViewBtn 是否显示切换周视图和月视图按钮  <isNotNull>
 * @param {boolean} options.showTodayBtn 是否显示回到今天按钮  <isNotNull>
 * @param {boolean} options.showLunar 是否显示农历  <isNotNull>
 * @param {string} options.themeStyle 日程安排UI主题 1.timeArrange 2.暂无  <isNotNull>
 * @param {function} options.callback 回调函数 <isNotNull>
 */
;(function(cmp){
    var CMP_DTPICKER_I18N_LOADED = false;
    cmp.i18n.load(cmpBASEPATH+'/i18n/', 'cmp-dtPicker',function(){
        CMP_DTPICKER_I18N_LOADED = true;
        cmp.event.trigger("cmp-dateCalender-init",document);
    },cmpBuildversion);
   

    // 滑动组件--适用于日历切换
    function Move(ele,options){
        this.init(ele,options);
    };
    Move.prototype = {
        //获取CSS3内核值，用于兼容动画切换
        getCSS3Style:function(style){
            var self = this;
            //获得CSS3前缀
            var _elementStyle = document.createElement('div').style;
            var _vendor=function (styleWeb) {
                if(styleWeb in _elementStyle) return styleWeb;
                var vendors = ['webkit', 'Moz', 'ms', 'O'],
                    i = 0, l = vendors.length;
                for ( ; i < l; i++ ) {
                    var _style=vendors[i] + styleWeb.charAt(0).toUpperCase() + styleWeb.substr(1);
                    if ( _style in _elementStyle ) return vendors[i];
                }
                return false;
            }
            var vendor2=_vendor(style);
            if ( vendor2 === false ) return false;
            if ( vendor2 === style ) return style;
            return vendor2 + style.charAt(0).toUpperCase() + style.substr(1);
        },
        init:function(ele,options){
            var self=this;
            //判断是pc端还是移动端
            var isTouchPad = (/hp-tablet/gi).test(navigator.appVersion);
            self.hasTouch = 'ontouchstart' in window && !isTouchPad;
            self.START_EV = self.hasTouch ? 'touchstart' : 'mousedown',
            self.MOVE_EV = self.hasTouch ? 'touchmove' : 'mousemove',
            self.END_EV = self.hasTouch ? 'touchend' : 'mouseup';
            self._transform = self.getCSS3Style("transform");
            self._transition = self.getCSS3Style("transition");
            //参数
            self.ele=typeof ele==="object"?ele:document.querySelector(ele);
            self.options={
                zoom:false,
                scale:false,
                //参数
                zoomNum:1,
                minZoom:1,
                maxZoom:5,
                minX:0,
                minY:0,
                maxX:0,
                maxY:0,
                onRefresh:null,
                useCapture:true
            };
            for (i in options) self.options[i] = options[i];
            self.refresh();
            self.events();
        },
        //刷新数据
        refresh:function(){
            if (this.options.onRefresh) this.options.onRefresh.call(this);
        },
        //获取匹配元素在当前视口的相对偏移
        offset:function(){
            if ( !this.ele ) return null;
            var box = this.ele.getBoundingClientRect(),
                top  = box.top  + window.pageYOffset,
                left = box.left + window.pageXOffset;
            return {left:left, top:top};
        },
        //获取css3矩形变换值
        transform:function(){
            var self = this;
            var matrix = window.getComputedStyle(self.ele, null)[self._transform],
                x, y, sx, sy , deg ,skX ,skY;
            if(matrix=="none" || !matrix) return { x: 0, y: 0, sx:1, sy:1, deg:0, skX:0, skY:0};
            var str=matrix.match(/\(.+?\)/g)[0];
            matrix = str.substring(1,(str.length-1)).split(",");
            if(matrix.length==6){
                x = +(matrix[4]);
                y = +(matrix[5]);
                sx = +(matrix[0]);
                sy = +(matrix[3]);
                deg=Math.round(Math.acos(+(matrix[0]))/Math.PI*180);
                skX=Math.round(Math.atan(+(matrix[2]))/Math.PI*180);
                skY=Math.round(Math.atan(+(matrix[1]))/Math.PI*180);
            }else{
                x = +(matrix[12]);
                y = +(matrix[13]);
                sx = +(matrix[0]);
                sy = +(matrix[5]);
            }
            return { x: x, y: y, sx:sx, sy:sy, deg:deg, skX:skX, skY:skY};
        },
        //滑动开始
        start:function(event){
            var self = this;
            self.options.scale=false;
            var touch = self.hasTouch ? event.targetTouches[0] : event;
            if(self.hasTouch && event.touches.length > 1){
                self.options.scale=true;
                if(self.options.zoom){
                    var touch1 = event.touches[0];
                    var touch2 = event.touches[1];
                    var moveX=touch1.pageX-touch2.pageX;
                    var moveY=touch1.pageY-touch2.pageY;
                    var c1=Math.abs(moveX);
                    var c2=Math.abs(moveY);
                    self.options.touchesDistStart = Math.sqrt(c1*c1+c2*c2);
                    self.options.scaleStart=self.options.zoomNum;

                    var pageX=touch2.pageX+moveX/2;
                    var pageY=touch2.pageY+moveY/2;
                    var offsetX=self.offset().left;
                    var offsetY=self.offset().top;
                    self.options.x0=pageX-offsetX+self.transform().x;
                    self.options.y0=pageY-offsetY+self.transform().y;
                    self.options.x1=(self.options.x0-self.transform().x)/self.options.zoomNum;
                    self.options.y1=(self.options.y0-self.transform().y)/self.options.zoomNum;
                }
            }else{
                self.options.scale=false;
                //取第一个touch的坐标值
                self.startPos = {
                    events:event,
                    pageX:touch.pageX,
                    pageY:touch.pageY,
                    time:+new Date,
                    zoomNum:self.options.zoomNum,
                    translateX:self.transform().x,
                    translateY:self.transform().y
                };
                //判断横向滑动还是纵向滑动
                self.options.prePageX = touch.pageX;
                self.options.prePageY = touch.pageY;
                if(self.options.startFn){
                    self.options.startFn.call(self,self.startPos);
                }
            }
        },
        //移动
        move:function(event){
            var self = this;
            var touch = self.hasTouch ? event.targetTouches[0] : event;
            if(self.hasTouch && event.touches.length > 1){
                if(self.options.zoom){
                    var touch1 = event.touches[0];
                    var touch2 = event.touches[1];
                    var moveX=touch1.pageX-touch2.pageX;
                    var moveY=touch1.pageY-touch2.pageY;
                    var c1=Math.abs(moveX);
                    var c2=Math.abs(moveY);
                    self.options.touchesDist = Math.sqrt(c1*c1+c2*c2);
                    self.options.zoomNum = self.options.touchesDist / self.options.touchesDistStart *self.options.scaleStart;
                    if(self.options.zoomNum < self.options.minZoom) self.options.zoomNum = self.options.minZoom;
                    else if(self.options.zoomNum > self.options.maxZoom) self.options.zoomNum = self.options.maxZoom;

                    var x=self.options.x1*self.options.zoomNum-self.options.x0;
                    var y=self.options.y1*self.options.zoomNum-self.options.y0;

                    if(self.options.zoomFn){
                        self.zoomPos={
                            events:event,
                            x:-x,
                            y:-y,
                            zoomNum: self.options.zoomNum
                        }
                        self.options.zoomFn.call(self,self.zoomPos);
                    }
                }
            }else{
                self.movePos = {
                    events:event,
                    x:touch.pageX - self.startPos.pageX,
                    y:touch.pageY - self.startPos.pageY,
                    scale:self.options.scale,
                    zoomNum: self.options.zoomNum,
                    startPointX:self.startPos.translateX,
                    startPointY:self.startPos.translateY,
                    translateX:self.transform().x,
                    translateY:self.transform().y,
                    deltaX:touch.pageX-self.options.prePageX,
                    deltaY:touch.pageY-self.options.prePageY
                };
                self.isScrolling = Math.abs(touch.pageX-self.options.prePageX) < Math.abs(touch.pageY-self.options.prePageY) ? 1:0;    //isScrolling为1时，表示纵向滑动，0为横向滑动
                self.options.prePageX = touch.pageX;
                self.options.prePageY = touch.pageY;
                if(self.options.moveFn){
                    self.options.moveFn.call(self,self.movePos,self.isScrolling);
                }
            }
        },
        //滑动释放
        end:function(event){
            var self = this;
            var touch = self.hasTouch ? event.changedTouches[0] : event;
            self.endPos = {
                events:event,
                x:touch.pageX - self.startPos.pageX,
                y:touch.pageY - self.startPos.pageY,
                duration:Number(+new Date - self.startPos.time),
                scale:self.options.scale,
                zoomNum: self.options.zoomNum,
                startPointX:self.startPos.translateX,
                startPointY:self.startPos.translateY,
                translateX:self.transform().x,
                translateY:self.transform().y
            };
            if(self.options.endFn){
                //调用endFn将当前this传递给endFn方法，再将两个参数传递给endFn方法。
                self.options.endFn.call(self,self.endPos,self.isScrolling);
            }
        },
        //事件
        events:function(){
            //绑定事件
            var self=this;
            //开始
            function _start(event){
                self.start(event);
                self.ele.addEventListener(self.MOVE_EV,_move,self.options.useCapture);
                self.ele.addEventListener(self.END_EV,_end,self.options.useCapture);
            }
            //滑动
            function _move(event){
                self.move(event);
            }
            //结束
            function _end(event){
                self.end(event);
                self.ele.removeEventListener(self.MOVE_EV,_move,self.options.useCapture);
                self.ele.removeEventListener(self.END_EV,_end,self.options.useCapture);
            }
            self.ele.addEventListener(self.START_EV,_start,self.options.useCapture);
        }
    };
    

    // 日历组件
    function DateCalender(ele,options){
        this.init(ele,options);
    };
    //供开发能使用的原型链
    DateCalender.prototype = {
        init:function(ele,options){
            if(!CMP_DTPICKER_I18N_LOADED){
                document.addEventListener("cmp-dateCalender-init",function(){
                    _dateCalender.init(ele,options);
                });
            }else {
                _dateCalender.init(ele,options);
            }
            
        },
        refresh:function(options){
            _dateCalender.refresh(options);
        },
        //重置预定数据
        setOrderD : function(orderDs){
            _dateCalender.setOrderD(orderDs);
        },
        callback : function(){
            _dateCalender.callback();
        }
    };

    // 内部方法--只是组件内部使用
    var _dateCalender = {
        //获取CSS3内核值，用于兼容动画切换
        getCSS3Style:function(style){
            var self = this;
            //获得CSS3前缀
            var _elementStyle = document.createElement('div').style;
            var _vendor=function (style) {
                if(style in _elementStyle) return style;
                var vendors = ['webkit', 'Moz', 'ms', 'O'],
                    i = 0,
                    l = vendors.length;
        
                for ( ; i < l; i++ ) {
                    var _style=vendors[i] + style.charAt(0).toUpperCase() + style.substr(1);
                    if ( _style in _elementStyle ) return vendors[i];
                }
                return false;
            }
            var vendor2=_vendor(style);
            if ( vendor2 === false ) return false;
            if ( vendor2 === style ) return style;
            return vendor2 + style.charAt(0).toUpperCase() + style.substr(1);
        },
        init:function(ele,options){
            var self = this;
            self.ele = null;
            self.options = null;
            self.choosedDate = null;
            self._transform = self.getCSS3Style("transform");
            self._transition = self.getCSS3Style("transition");
            self.initStyle(ele,options);
            self.initData();
            self.events();
        },

        initStyle:function(ele,options){
            var self = this;
            var date=new Date();
            var lang=cmp.language;
            self.ele=typeof ele==="object"?ele:document.querySelector(ele);;
            self.options=cmp.extend({
                y:date.getFullYear(),
                m:date.getMonth()+1,
                d:date.getDate(),
                type:"week",
                yText:cmp.i18n("cmp.dtPicker.year"),
                mText:cmp.i18n("cmp.dtPicker.month"),
                dText:cmp.i18n("cmp.dtPicker.day"),
                nText:cmp.i18n("cmp.dtPicker.today"),
                wArr:[cmp.i18n("cmp.dtPicker.seven"),cmp.i18n("cmp.dtPicker.one"),//头部周一到周日
                cmp.i18n("cmp.dtPicker.two"),cmp.i18n("cmp.dtPicker.three"),
                cmp.i18n("cmp.dtPicker.four"),cmp.i18n("cmp.dtPicker.five"),
                cmp.i18n("cmp.dtPicker.six")],
                mArr:[31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],
                orderD:[],  //["2016-12-07","2016-12-10"]
                beginYear:1900, //开始年
                endYear:2101, //结束年
                uichangeToCallback:true,//是否只要ui改变了就要回调函数
                dateSwitch:false,//是否点击日期切换按钮就切换日期
                // 新增参数
                switchMothBtn:false,//是否显示切换月视图前进后退按钮
                switchViewBtn:true,//是否显示切换周视图和月视图按钮
                showTodayBtn:true,//是否显示回到今天按钮
                showLunar:true,//是否显示农历
                themeStyle:"" //1.timeArrange:日程安排主题--日程安排或者会议室使用。2.待增加
            },options);
            if(lang !== "zh_CN" && lang !== "zh_TW"){ //不是中文或繁体情况下始终屏蔽农历
                self.options.showLunar = false;
            }
            //今天
            self.options.nowDate=self.dateStr(date.getFullYear(),date.getMonth()+1,date.getDate());
            var choosedDate = self.dateStr(self.options.y,self.options.m,self.options.d);
            self.choosedDate = choosedDate == self.options.nowDate?null:choosedDate;//判断是否已经有已选日期了
            
            if(self.options.themeStyle){
                self.ele.classList.add(self.options.themeStyle+"-theme");
            }
            if(cmp.device.orientation() == "portrait" && document.body.offsetHeight < 550 ){
                self.options.themeStyle = "androidPad-theme";
                self.ele.classList.add("androidPad-theme");
            }
            // self.init();
            // self.events();
        },
        initData:function(){
            var self=this;
            var weekHtml="";
            for(var i=0,len=self.options.wArr.length;i<len;i++){
                weekHtml+='<li class="week cmp-sup-fc1">'+self.options.wArr[i]+'</li>';
            }
            /*头部*/
            var hHtml='<div class="cmp-dtcHeader cmp-white-bg">';
            if(self.options.switchMothBtn && self.options.type=="month"){
                hHtml+='<div class="dtcTitle ">'+
                '<div class="arrow maxPrev"><span class="calender-icon-arrow-year see-icon-v5-common-double-arrow-left"></span></div>'+
                '<div class="arrow prev"> '+
                '<span class="calender-icon-arrow see-icon-v5-common-arrow-plane-left"></span> '+
                '</div>';
                hHtml+='<div class="arrow title dateswitch cmp-main-fc"></div>';
                hHtml+='<div class="arrow next"> '+
                '<span class="calender-icon-arrow see-icon-v5-common-arrow-plane-right"></span> '+
                '</div>'+
                '<div class="arrow maxNext"><span class="calender-icon-arrow-year see-icon-v5-common-double-arrow-right"></span></div>'+
                '</div>';
            }else{
                if( self.ele.classList.contains("timeArrange-theme") ){
                    hHtml+='<div class="title dateswitch cmp-main-fc"><span class="title-month"></span><span class="title-year"></span></div>';
                }else{
                    hHtml+='<div class="title dateswitch"></div>';
                }
                
            }
            
            if(self.options.showTodayBtn){
                hHtml+='<div class="right today">'+self.options.nText+'</div>';
            }
            hHtml+='</div>';

            /*内容*/
            var lunar =  self.options.showLunar?"":"noLunar";
            var cHtml='<div class="cmp-dtcContent cmp-white-bg '+lunar+'"><ul class="ul_weekLine">'+weekHtml+'</ul>';
            cHtml+='<ul class="ul_content"></ul>';
            if(self.options.switchViewBtn){
                cHtml+='<div class="show"><i class="see-icon-v5-common-unorup"></i></div>';
            }
            cHtml+='</div>';
                
            self.ele.innerHTML=hHtml+cHtml;
            self.title=self.ele.querySelector(".title");
            self.today=self.ele.querySelector(".today");
            self.dateswitch = self.ele.querySelector(".dateswitch");
            self.prev = self.ele.querySelector(".arrow.prev");//切换上一个月按钮
            self.next = self.ele.querySelector(".arrow.next");//切换下一个月按钮
            self.maxPrev = self.ele.querySelector(".arrow.maxPrev");//切换上一年份按钮
            self.maxNext = self.ele.querySelector(".arrow.maxNext");//切换下一年按钮
            var content = self.ele.querySelector(".ul_content");
            content.setAttribute("id","content_"+cmp.buildUUID());  
            self.content=content;
            self.show=self.ele.querySelector(".show");
            self.box=self.ele.querySelector(".cmp-dtcContent");
            self.boxW=self.box.offsetWidth;
            self.orderD2Map();
            self.refresh();

            self.callback(self.options.y,self.options.m,self.options.d);
        },
        refresh:function(options){
            var self = this;
            if(!self.options)return;
            options = cmp.extend(self.options,options);
            self.setTitle(self.options.y,self.options.m,self.options.d);
            if(typeof options == "undefined"){
                var now = new Date(), ny = now.getFullYear(),nm = now.getMonth() + 1,nd = now.getDate();
                self.options.selectDate = self.dateStr(ny,nm,nd);
            }else {
                self.options.selectDate = self.dateStr(options.y,options.m,options.d);
            }
            if(self.options.type==="week"){
                self.weekRender(self.options.y,self.options.m,self.options.d);
                self.show && self.show.classList.remove("hide");
                self.ele && self.ele.classList.remove("cmp-calender-monthView");
                // removeClass(self.show,"hide");
            }else if(self.options.type==="month"){ //月视图
                self.monthRender(self.options.y,self.options.m);
                self.show && self.show.classList.add("hide");
                self.ele && self.ele.classList.add("cmp-calender-monthView");
                
                // addClass(self.show,"hide");
            }
        },
        //刷新UI
        refreshUI:function(){
            var self = this;
            self.boxW=self.box.offsetWidth;
            self.content.style.width = self.boxW*3+"px";
            self.content.style.transform = "translate(-"+self.boxW+"px,0px)";
            for(var i=0,len=3;i<len;i++){
                self.content.querySelectorAll(".li1")[i].style.width = self.boxW+"px";
            }
            if(self.ele.classList.contains("androidPad-theme")){
                self.ele.classList.remove("androidPad-theme");
            }else{
                self.ele.classList.add("androidPad-theme");
            }
        },
        //重置预定数据
        setOrderD:function(orderDs){
            var self = this;
            self.options.orderD = orderDs;
            self.orderD2Map();
            var li=self.content.querySelectorAll(".li1")[-self.pos];
            var dateBlock = li.querySelector(".ul_dateBlock");
            var dateLiDoms = dateBlock.querySelectorAll("li");
            var orderLiDoms = dateBlock.querySelectorAll(".order");
            if(orderLiDoms.length > 0){
                var j = 0,length = orderLiDoms.length;
                for(;j<length;j++){
                    orderLiDoms[j] && orderLiDoms[j].classList.remove("order");
                    // removeClass(orderLiDoms[j],"order");

                }
            }
            if(orderDs.length > 0){
                var i = 0,len = dateLiDoms.length,count = Object.keys(self.orderDMap).length;
                for(;i<len;i++){
                    if(!count) break;
                    var key = dateLiDoms[i].getAttribute("data-ymd");
                    if(self.orderDMap[key]){
                        dateLiDoms[i] && dateLiDoms[i].classList.add("order");
                        // addClass(dateLiDoms[i],"order");
                        count --
                    }
                }
            }
        },
        orderD2Map : function(){
            var self = this;
            self.orderDMap = {};
            if(self.options.orderD && self.options.orderD.length > 0){
                var i = 0,len = self.options.orderD.length;
                for(;i<len;i++){
                    self.orderDMap[self.options.orderD[i]] = self.options.orderD[i];
                }
            }
        },
        //设置头部标题
        setTitle:function(y,m,d){
            var self = this;
            var lang=cmp.language;
            // var moths = ['January ','February ','March ','April ','May ','June ','July ',
            //     'August ','September ','October ','November ','December '];
            // Jan. Feb. Mar. Apr. May. Jun. Jul. Aug. Sep. Oct. Nov. Dec
            var moths = ['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];
            var i= 0,len=moths.length;
            if(lang === "en"){  //英文状态
                for(i;i<len;i++){
                    if(self.ele.classList.contains("timeArrange-theme")){
                        var dayNumber;
                        if(d == 1 || d ==3 ){
                            dayNumber = d;  //+"st"
                        }else if(d == 2){
                            dayNumber = d; //+"nd"
                        }else{
                            dayNumber = d; //+"th"
                        }
                        self.title.querySelector(".title-month").innerHTML = moths[(m-1)] + dayNumber +",";
                        self.title.querySelector(".title-year").innerHTML = y;
                    }else{
                        self.title.innerHTML= moths[(m-1)] + d +', '+ y;
                    }
                }
            }else{
                if(self.ele.classList.contains("timeArrange-theme")){
                    self.title.querySelector(".title-month").innerHTML = m+self.options.mText;
                    self.title.querySelector(".title-year").innerHTML = y;
                }else{
                    self.title.innerHTML=y+self.options.yText+m+self.options.mText;//+d+self.options.dText
                }
            }
        },
        //时间格式
        dateStr:function(y,m,d){
            m=m<10?"0"+m:m;
            d=d<10?"0"+d:d;
            var dateStr=y+"-"+m+"-"+d;
            return dateStr;
        },
        //时间对象
        dateObj:function(str){
            if(str){
                var arr=str.split("-");
                return [+arr[0],+arr[1],+arr[2]];
            }else{
                return false;
            }
        },
        //是否是平年
        IsPinYear:function(year){
            return(0 == year%4 && (year%100 !=0 || year%400 == 0));
        },
        //当前月
        mDays:function(y,m){
            var self = this;
            var n = self.options.mArr[m-1];
            if (m==2 && self.IsPinYear(y)) n++;
            return n;
        },
        //单个节点
        li:function(y,m,d,gray){
            var self = this;
            if(y===0){
                return '<li class="date null"></li>';
            }
            var date= new Date(y,m-1,d);
            var dateStr=self.dateStr(y,m,d);
            var liClass="date";
            if(dateStr===self.options.nowDate){
                liClass+=" now";
                if(self.options.type == "week" && !self.choosedDate){
                    liClass += " selected";
                }
            }

            if(dateStr===self.options.selectDate){
                liClass+=" selected";
            }
            if(dateStr === self.choosedDate){
                liClass += " choosed";
            }
            if(self.orderDMap[dateStr]){
                liClass+=" order";
            }

            if(gray){
                liClass+=" gray";
            }
            if(d===1){
                liClass+=" first";
            }
            // 农历插件
            var LunarDate = {
                madd: new Array(0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334),
                HsString: '甲乙丙丁戊己庚辛壬癸',
                EbString: '子丑寅卯辰巳午未申酉戌亥',
                NumString: "一二三四五六七八九十",
                MonString: "正二三四五六七八九十冬腊",
                CalendarData: new Array(0xA4B, 0x5164B, 0x6A5, 0x6D4, 0x415B5, 0x2B6, 0x957, 0x2092F, 0x497, 0x60C96, 0xD4A, 0xEA5, 0x50DA9, 0x5AD, 0x2B6, 0x3126E, 0x92E, 0x7192D, 0xC95, 0xD4A, 0x61B4A, 0xB55, 0x56A, 0x4155B, 0x25D, 0x92D, 0x2192B, 0xA95, 0x71695, 0x6CA, 0xB55, 0x50AB5, 0x4DA, 0xA5B, 0x30A57, 0x52B, 0x8152A, 0xE95, 0x6AA, 0x615AA, 0xAB5, 0x4B6, 0x414AE, 0xA57, 0x526, 0x31D26, 0xD95, 0x70B55, 0x56A, 0x96D, 0x5095D, 0x4AD, 0xA4D, 0x41A4D, 0xD25, 0x81AA5, 0xB54, 0xB6A, 0x612DA, 0x95B, 0x49B, 0x41497, 0xA4B, 0xA164B, 0x6A5, 0x6D4, 0x615B4, 0xAB6, 0x957, 0x5092F, 0x497, 0x64B, 0x30D4A, 0xEA5, 0x80D65, 0x5AC, 0xAB6, 0x5126D, 0x92E, 0xC96, 0x41A95, 0xD4A, 0xDA5, 0x20B55, 0x56A, 0x7155B, 0x25D, 0x92D, 0x5192B, 0xA95, 0xB4A, 0x416AA, 0xAD5, 0x90AB5, 0x4BA, 0xA5B, 0x60A57, 0x52B, 0xA93, 0x40E95),
                Year: null,
                Month: null,
                Day: null,
                TheDate: null,
                GetBit: function(m, n){
                    return (m >> n) & 1;
                },
                e2c: function(){
                    this.TheDate = (arguments.length != 3) ? new Date(): new Date(arguments[0], arguments[1], arguments[2]);
                    var total, m, n, k;
                    var isEnd = false;
                    var tmp = this.TheDate.getFullYear();
                    total = (tmp - 1921) * 365 + Math.floor((tmp - 1921) / 4) + this.madd[this.TheDate.getMonth()] + this.TheDate.getDate() - 38;
                    if (this.TheDate.getYear() % 4 == 0 && this.TheDate.getMonth() > 1) {
                        total++;
                    }
                    for (m = 0; ; m++) {
                        k = (this.CalendarData[m] < 0xfff) ? 11: 12;
                        for (n = k; n >= 0; n--) {
                            if (total <= 29 + this.GetBit(this.CalendarData[m], n)) {
                                isEnd = true;
                                break;
                            }
                            total = total - 29 - this.GetBit(this.CalendarData[m], n);
                        }
                        if (isEnd)
                            break;
                    }
                    this.Year = 1921 + m;
                    this.Month = k - n + 1;
                    this.Day = total;
                    if (k == 12) {
                        if (this.Month == Math.floor(this.CalendarData[m] / 0x10000) + 1) {
                            this.Month = 1 - this.Month;
                        }
                        if (this.Month > Math.floor(this.CalendarData[m] / 0x10000) + 1) {
                            this.Month--;
                        }
                    }
                },
                GetcDateString: function(){
                    var tmp = "";
                    //tmp += this.HsString.charAt((this.Year - 4) % 10);
                    //tmp += this.EbString.charAt((this.Year - 4) % 12);
                    //tmp += "年 ";
                    var MonthString = '';
                    if(this.Day == 1){
                        if (this.Month < 1) {
                            MonthString += "(闰)";
                            MonthString += this.MonString.charAt(-this.Month - 1);
                        } else {
                            MonthString += this.MonString.charAt(this.Month - 1);
                        }
                        MonthString += "月";
                    }

                    tmp += (this.Day == 1 ) ? MonthString : ((this.Day < 11) ? "初": ((this.Day < 20) ? "十": (this.Day == 20) ? "二十" :  ((this.Day < 30) ? "廿": "三十")   ));
                    if(this.Day != 1){
                        if (this.Day % 10 != 0 || this.Day == 10) {
                            tmp += this.NumString.charAt((this.Day - 1) % 10);
                        }
                    }
                    return tmp;
                },
                GetLunarDay: function(solarYear, solarMonth, solarDay) {
                    if (solarYear < 1921 || solarYear > 2050) {
                        return "";
                    } else {
                        solarMonth = (parseInt(solarMonth) > 0) ? (solarMonth - 1): 11;
                        this.e2c(solarYear, solarMonth, solarDay);
                        return this.GetcDateString();
                    }
                }
            };
            // var thatDay = liClass.indexOf("now")>-1?cmp.i18n("cmp.dtPicker.today"):d;
            var li='<li class="'+liClass+'" data-ymd='+dateStr+'>',
                _class = dateStr===self.options.selectDate?'cmp-reverse-fc-no':(liClass.indexOf("now")>-1?'cmp-theme-fc':((liClass === 'date gray' || liClass === 'date gray first') ? 'cmp-sup-fc1' : 'cmp-main-fc'));
            // if(cmp.language == "zh_CN"){  //判断是中文才显示农历
                li += '<div class="number-day"><span class="number-name ' + _class + '">'+d+'</span>'; //thatDay
                if(self.options.showLunar){
                    li += '<span class="lunar-week">'+LunarDate.GetLunarDay(y, m, d)+'</span>';
                }
            // }else {
            //     li += '<div class="number-day" style="line-height: 40px;">'+thatDay;
            // }
            li += '<i class="dot"></i></div>'
                +'</li>';
            return li;
        },
        //拼字符串
        ulHtml:function(arrs,y,m,d){
            var self = this;
            var cHtml="",ulHtml="";
            var dateStr=self.dateStr(y,m,d);
            for(var i=0,len=arrs.length;i<len;i++){
                ulHtml+='<ul class="ul_dateLine">';
                for(var j=0,jlen=arrs[i].length;j<jlen;j++){
                    ulHtml+=self.li.apply(self,arrs[i][j]);//将数组里面的值以一个一个的参数形式传递给li方法。
                }
                ulHtml+='</ul>';
            }
            cHtml+='<li class="li1" style="width:'+self.boxW+'px" data-ymd='+dateStr+'>'
                +'<div class="ul_dateBlock">'+ulHtml+'</div>'
                +'</li>';
            return cHtml;
        },
        //周
        weekRender:function(y,m,d,choosed){
            var self = this;
            var cHtml="";
            var pWeek=[[]],cWeek=[[]],nWeek=[[]];
            var pWeek=self.weekHtml(y,m,d,-1);
            var cWeek=self.weekHtml(y,m,d,0);
            var nWeek=self.weekHtml(y,m,d,1);
            cHtml=pWeek+cWeek+nWeek;
            self.content.innerHTML=cHtml;
            if(!pWeek){
                self.isBegin=true;
                self.pos=0;
            }else{
                self.isBegin=false;
                self.pos=-1;
            }
            if(!nWeek){
                self.isEnd=true;
            }else{
                self.isEnd=false;
            }
            self.content.style[self._transform]='translate('+(self.pos*self.boxW)+'px,0px)';
            var index=self.content.querySelectorAll(".li1").length;
            self.content.style['width']=self.boxW*index+'px';
        },
        //周html
        weekHtml:function(y,m,d,num){
            var self = this;
            var date= new Date(y,m-1,d);
            var index=date.getDay();
            var wArr=[[]];
            var pDays=self.pDays(y,m,d,(7+index));
            var nDays=self.nDays(y,m,d,(13-index));
            var allDays=[];
            var cHtml="";
            pDays.forEach(function(day){
                allDays.push(day);
            });
            allDays.push([y,m,d]);
            nDays.forEach(function(day){
                allDays.push(day);
            });

            var startD=allDays[7*num+7];
            var endD=allDays[7*num+13];
            if(!endD[0]&&!startD[0]){
                return "";
            }else{
                for(var i=0;i<7;i++){
                    wArr[0].push(allDays[7*num+7+i]);
                }
            }
            return self.ulHtml(wArr,endD[0]||startD[0],endD[1]||startD[1],endD[2]||startD[2]);
        },
        //月
        monthRender:function(y,m){
            var self = this;
            var cHtml="";
            var pMouth=self.mouthHtml(y,m,-1);
            var cMouth=self.mouthHtml(y,m,0);
            var nMouth=self.mouthHtml(y,m,1);
            cHtml=pMouth+cMouth+nMouth;
            self.content.innerHTML=cHtml;
            if(!pMouth){
                self.isBegin=true;
                self.pos=0;
            }else{
                self.isBegin=false;
                self.pos=-1;
            }
            if(!nMouth){
                self.isEnd=true;
            }else{
                self.isEnd=false;
            }
            self.content.style[self._transform]='translate('+(self.pos*self.boxW)+'px,0px)';
            var index=self.content.querySelectorAll(".li1").length;
            self.content.style['width']=self.boxW*index+'px';
            if(pMouth == ""){
                self.prev && self.prev.querySelector(".calender-icon-arrow").classList.add("cmp-hidden");
            }else{
                self.prev && self.prev.querySelector(".calender-icon-arrow").classList.remove("cmp-hidden"); 
            }
            if(nMouth ==""){
                self.next && self.next.querySelector(".calender-icon-arrow").classList.add("cmp-hidden");
            }else{
                self.next && self.next.querySelector(".calender-icon-arrow").classList.remove("cmp-hidden");
            }
        },
        //月html
        mouthHtml:function(y,m,num){ //不会出现联跳两个月的情况
            var self = this;
            var mArr=[];
            var yy,mm=m+num;
            if(mm<1){
                yy=y-1;
                mm=12;
            }else if(mm>12){
                yy=y+1;
                mm=1;
            }else{
                yy=y;
            }

            if(yy<self.options.beginYear){
                return "";
            }else if(yy>self.options.endYear){
                return "";
            }

            var date= new Date(yy,mm-1,1);
            var index=date.getDay();
            var pDays=self.pDays(yy,mm,1,index);
            var nDays=self.nDays(yy,mm,1,(41-index));
            var mDays=self.mDays(yy,mm);
            var allDays=[];
            var cHtml="";
            pDays.forEach(function(day){
                day.push(true);
                allDays.push(day);
            });
            allDays.push([yy,mm,1]);
            nDays.forEach(function(day,i){
                if(i>=(mDays-1)){
                    day.push(true);
                }
                allDays.push(day);
            });
            for(var i=0;i<6;i++){
                if(!mArr[i]){
                    mArr[i]=[];
                }
                for(var j=0;j<7;j++){
                    mArr[i].push(allDays[i*7+j]);
                }
            }
            return self.ulHtml(mArr,yy,mm,1);

        },
        //前面的几天
        pDays:function(y,m,d,len){
            var self = this;
            var pDaysArr=[];
            if(d>len){
                for(var i=0;i<len;i++){
                    var num=len-i;
                    var ymd=[y,m,d-num];
                    pDaysArr.push(ymd);
                }
            }else{
                var ymd,mm,yy,dd;
                if(m==1){
                    mm=12;
                    yy=y-1;
                }else{
                    mm=m-1;
                    yy=y;
                }
                var pDays=self.mDays(yy,mm);

                for(var i=1;i<=len;i++){
                    if(d-i>=1){
                        ymd=[y,m,d-i];
                    }else{
                        dd=pDays+d-i;
                        ymd=[yy,mm,dd];
                        if(yy<self.options.beginYear){
                            ymd=[0,0,0];
                        }
                    }
                    pDaysArr.unshift(ymd);
                }
            }
            return pDaysArr;
        },
        //后面的几天
        nDays:function(y,m,d,len){
            var self = this;
            var nDaysArr=[];
            if(d+len<=days){
                for(var i=1;i<=len;i++){
                    var ymd=[y,m,d+i];
                    nDaysArr.push(ymd);
                }
            }else{
                var ymd,mm,yy,dd;
                var days=self.mDays(y,m);
                if(m==12){
                    mm=1;
                    yy=y+1;
                }else{
                    mm=m+1;
                    yy=y;
                }

                for(var i=1;i<=len;i++){
                    if(d+i<=days){
                        ymd=[y,m,d+i];
                    }else{
                        dd=d+i-days;
                        ymd=[yy,mm,dd];
                        if(yy>self.options.endYear){
                            ymd=[0,0,0];
                        }
                    }
                    nDaysArr.push(ymd);
                }
            }
            return nDaysArr;
        },
        //回调函数
        callback:function(y,m,d){
            var self = this;
            var data= self.assemblyResult(y,m,d);
            var cmp_dtcContent = self.ele.querySelector('.cmp-dtcContent');
            var ul_weekLine = cmp_dtcContent.querySelector('.ul_weekLine');
            var ul_dateBlock = self.content.querySelectorAll('li.li1')[1].querySelector('.ul_dateBlock');
            var ul_dateLine = ul_dateBlock.querySelectorAll('.ul_dateLine');
            var lastUl = ul_dateLine[ul_dateLine.length-1];

            self.ele && self.ele.classList.remove("month-view-max");

            if(self.options.type == "month" ){   //月视图
                var dateAll = lastUl.querySelectorAll('.gray');
                if(dateAll.length == 7){
                    lastUl.remove();
                }
                var ulLineDom = ul_dateBlock.querySelectorAll("ul.ul_dateLine");
                if(ulLineDom.length==6){
                    self.ele.classList.add("month-view-max");//6行视图,缩小间距样式
                }
            }else if(self.options.type == "week"){  //周视图
                var choosed = ul_dateLine[0].querySelector('.choosed');
                var selected = ul_dateLine[0].querySelector('.selected');
                var now = ul_dateLine[0].querySelector('.now');
                var date=new Date();
                if(self.choosedDate && choosed){  //传递了值得情况
                    var choosedYMD = self.dateObj(self.choosedDate);
                    self.setTitle(choosedYMD[0],choosedYMD[1],choosedYMD[2]);
                    data.y = choosedYMD[0];
                    data.m = choosedYMD[1];
                    data.d = choosedYMD[2];
                }else{
                    if(!selected){
                        var first=self.ele.querySelectorAll(".li1")[0];
                        var firstYMD=self.dateObj(first.getAttribute("data-ymd"));
                        ul_dateLine[0].querySelectorAll('.date')[0].classList.add('selected');
                        ul_dateLine[0].querySelectorAll('.date')[0].querySelector('.number-name').classList.remove('cmp-main-fc');
                        ul_dateLine[0].querySelectorAll('.date')[0].querySelector('.number-name').classList.add('cmp-reverse-fc-no');
                        if(date.getFullYear() == firstYMD[0] && (date.getMonth()+1) ==firstYMD[1] && (date.getDate()+1) == (firstYMD[2]+1) ){
                            self.setTitle(date.getFullYear(),(date.getMonth()+1),date.getDate()+1);
                            data.y = date.getFullYear();
                            data.m = (date.getMonth()+1);
                            data.d = date.getDate()+1;
                        }else{
                            firstYMD = self.transeDiffDate4Title(firstYMD);
                            self.setTitle(firstYMD[0],firstYMD[1],firstYMD[2]);
                            data.y = firstYMD[0];
                            data.m = firstYMD[1];
                            data.d = firstYMD[2];
                        }
                    }else{
                        self.setTitle(date.getFullYear(),(date.getMonth()+1),date.getDate());
                        if(!(data.y && data.m && data.d)){
                            data.y = date.getFullYear();
                            data.m = date.getMonth()+1;
                            data.d = date.getDate();
                        }

                    }
                }
                // cmp_dtcContent.style.height = "auto";
                // self.content.style.height = "auto";
            }
            if(self.today){
                if(data.value == self.options.nowDate){
                    self.today.classList.add("cmp-hidden");
                }else{
                    self.today.classList.remove("cmp-hidden");
                }
            }
            
            if(typeof self.options.callback==="function") self.options.callback.call(self,data);
        },
        transeDiffDate4Title:function(firstYMD){
            var bigM = [1,3,5,7,8,10,12];
            var smallM = [4,6,9,11];
            var y =firstYMD[0], m = firstYMD[1],d = firstYMD[2];
            if(bigM.indexOf(m) != -1){
                if(d == 31){
                    if(m == 12){
                        firstYMD[0] ++;
                        firstYMD[1]=1;
                        firstYMD[2]=1;
                    }else {
                        firstYMD[1] ++;
                        firstYMD[2]=1;
                    }
                }else {
                    firstYMD[2] ++;
                }
            }else if(smallM.indexOf(m) != -1){
                if(d == 30){
                    firstYMD[1] ++;
                    firstYMD[2]=1;
                }else {
                    firstYMD[2] ++;
                }
            }else {
                var febDayNum = ((y%4 == 0 && y%100 != 0) || y%400 == 0)?29:28;
                if(d == febDayNum){
                    firstYMD[1] ++;
                    firstYMD[2]=1;
                }else {
                    firstYMD[2] ++;
                }
            }
            return firstYMD;
        },
        //初始化
        events:function(){
            var self=this;
            var transitionend="ontransitionend" in window?'transitionend':'onwebkittransitionend';
            var contentMove = new Move(self.content,{
                startFn:function(obj){
                    this.ele.style[self._transition]="all 0ms";
                    this.ele.style[self._transform]="translate("+obj.translateX+"px,0px) translateZ(0px)";
                },
                moveFn:function(obj,isScrolling){
                    if(obj.scale) return;  //多个触摸点的时候禁止滑动
                    if(isScrolling === 0){
                        obj.events.preventDefault();  //阻止默认事件
                        var newX=obj.translateX+obj.deltaX;
                        this.ele.style[self._transform]="translate("+newX+"px,0px) translateZ(0px)";
                    }
                },
                endFn:function(obj,isScrolling){
                    var length=this.ele.querySelectorAll(".li1").length;
                    var first=this.ele.querySelectorAll(".li1")[0];
                    var firstYMD=self.dateObj(first.getAttribute("data-ymd"));
                    var last=this.ele.querySelectorAll(".li1")[length-1];
                    var lastYMD=self.dateObj(last.getAttribute("data-ymd"));
                    //右
                    if(obj.x>50){
                        if(self.isBegin){
                            this.ele.style[self._transition]="all 60ms cubic-bezier(0.1, 0.57, 0.1, 1)";
                            this.ele.style[self._transform]="translate(0px,0px) translateZ(0px)";
                        }else{
                            this.ele.style[self._transition]="all 300ms";
                            this.ele.style[self._transform]="translate(0px,0px) translateZ(0px)";
                            function _transitionendFirst(){
                                this.style[self._transition]="all 0ms";
                                var preDomSelected = first.querySelector("li.choosed");
                                var choosedYMD = [null,null,null];
                                //周
                                if(self.options.type==="week"){
                                    if(preDomSelected) {
                                        self.options.selectDate = self.choosedDate;
                                        choosedYMD = self.dateObj(self.choosedDate);
                                    }
                                    self.weekRender(firstYMD[0],firstYMD[1],firstYMD[2]);
                                }else if(self.options.type==="month"){
                                    self.setTitle(firstYMD[0],firstYMD[1],1);
                                    if(preDomSelected){
                                        self.options.selectDate = self.choosedDate;
                                        choosedYMD = self.dateObj(self.choosedDate);
                                    }else {
                                        var nowLi = first.querySelector("li.now");
                                        if(nowLi){
                                            self.options.selectDate = self.dateStr(self.options.y,self.options.m,self.options.d);
                                        }else{
                                            self.options.selectDate = self.dateStr(firstYMD[0],firstYMD[1],1);
                                        }
                                        firstYMD[2] = 1;
                                        choosedYMD = firstYMD;
                                    }
                                    self.monthRender(firstYMD[0],firstYMD[1]);
                                }
                                //if(that.options.uichangeToCallback){
                                self.callback(choosedYMD[0],choosedYMD[1],choosedYMD[2]);
                                //}
                                this.removeEventListener(transitionend,_transitionendFirst,false);
                            }
                            this.ele.addEventListener(transitionend,_transitionendFirst,false);
                        }
                    }else if(obj.x<-50){ //左
                        if(self.isEnd){
                            this.ele.style[self._transition]="all 60ms cubic-bezier(0.1, 0.57, 0.1, 1)";
                            this.ele.style[self._transform]="translate("+(-self.boxW)+"px,0px) translateZ(0px)";
                        }else{
                            this.ele.style[self._transition]="all 300ms";
                            this.ele.style[self._transform]="translate("+(self.pos-1)*self.boxW+"px,0px) translateZ(0px)";
                            function _transitionendLast(){
                                this.style[self._transition]="all 0ms";
                                //周
                                var nextDomSelected = last.querySelector("li.choosed");
                                var choosedYMD = [null,null,null];
                                if(self.options.type==="week"){
                                    if(nextDomSelected) {
                                        self.options.selectDate = self.choosedDate;
                                        choosedYMD = self.dateObj(self.choosedDate);
                                    }
                                    self.weekRender(lastYMD[0],lastYMD[1],lastYMD[2]);
                                }else if(self.options.type==="month"){
                                    self.setTitle(lastYMD[0],lastYMD[1],1);
                                    if(nextDomSelected){
                                        self.options.selectDate = self.choosedDate;
                                        choosedYMD = self.dateObj(self.choosedDate);
                                    }else {
                                        var nowLi = last.querySelector("li.now");
                                        if(nowLi){
                                            self.options.selectDate = self.dateStr(self.options.y,self.options.m,self.options.d);
                                        }else{
                                            self.options.selectDate = self.dateStr(lastYMD[0],lastYMD[1],1);
                                        }
                                        lastYMD[2] = 1;
                                        choosedYMD = lastYMD;
                                    }
                                    self.monthRender(lastYMD[0],lastYMD[1]);
                                }
                                //if(that.options.uichangeToCallback){
                                self.callback(choosedYMD[0],choosedYMD[1],choosedYMD[2]);
                                //}
                                this.removeEventListener(transitionend,_transitionendLast,false);
                            }
                            this.ele.addEventListener(transitionend,_transitionendLast,false);
                        }
                    }else{
                        this.ele.style[self._transition]="all 60ms cubic-bezier(0.1, 0.57, 0.1, 1)";
                        this.ele.style[self._transform]="translate("+self.pos*self.boxW+"px,0px) translateZ(0px)";
                    }
                }
            });
            //前进后退按钮
            if(self.prev && self.next && self.maxPrev && self.maxNext ){
                //上一个月
                cmp.event.click(self.prev,function(e){
                    if(e.target.classList.contains("cmp-hidden"))return;
                    self.switchBtnEvent("prev");
                });
                //下一个月
                cmp.event.click(self.next,function(e){
                    if(e.target.classList.contains("cmp-hidden"))return;
                    self.switchBtnEvent("next");
                });
                //上一年
                cmp.event.click(self.maxPrev,function(e){
                    if(e.target.classList.contains("cmp-hidden"))return;
                    self.switchBtnEvent("maxPrev");
                });
                //下一年
                cmp.event.click(self.maxNext,function(e){
                    if(e.target.classList.contains("cmp-hidden"))return;
                    self.switchBtnEvent("maxnext");
                });
            }
            //点击某一天
            self.content.addEventListener("click",function(event){
                var parent = event.target;
                while ( parent && parent.nodeType !== 9) {
                    if ( parent.nodeType === 1 && new RegExp("(^|\\s)date(\\s|$)", 'g').test(parent.className)) {
                        var ymd=self.dateObj(parent.getAttribute("data-ymd"));
                        self.choosedDate = self.dateStr(ymd[0],ymd[1],ymd[2]);
                        self.refresh({
                            y:ymd[0],
                            m:ymd[1],
                            d:ymd[2]
                        });
                        self.callback(ymd[0],ymd[1],ymd[2]);
                        self.setTitle(ymd[0],ymd[1],ymd[2]);
                        break;
                    }
                    parent = parent.parentNode;
                }
            },false);
            //回到今天按钮
            if(self.options.showTodayBtn){
                self.today.addEventListener("tap",function(event){
                    var date=new Date();
                    self.refresh({
                        y:date.getFullYear(),
                        m:date.getMonth()+1,
                        d:date.getDate()
                    });
                    var mark = false;
                    self.choosedDate = self.dateStr(date.getFullYear(),date.getMonth()+1,date.getDate());
                    self.callback(date.getFullYear(),(date.getMonth()+1),date.getDate(),mark);
                },false);
            }
            //给title上面的日期文本绑定事件---------此版本没有此功能，但是本人认为先预留此口子，后期必然会有客户要求直接跳转到他想要的某年某月
            if(self.options.dateSwitch){
                cmp.event.click(self.dateswitch,function(){
                    var datePicker = new cmp.DtPicker({
                        type:"date",
                        "value":self.options.selectDate || self.dateStr(self.options.y,self.options.m,self.options.d),
                        // "value":self.dateStr(self.options.y,self.options.m,self.options.d),
                        "beginYear":self.options.beginYear,
                        "endYear":self.options.endYear
                    });
                    datePicker.show(function(rs) {
                        var value = rs.value;
                        var ymd=self.dateObj(value);
                        self.choosedDate = self.dateStr(ymd[0],ymd[1],ymd[2]);
                        self.refresh({
                            y:ymd[0],
                            m:ymd[1],
                            d:ymd[2]
                        });
                        self.callback(ymd[0],ymd[1],ymd[2]);
                    });
                });
            }
            //类型
            function typeChange(){
                var li=self.content.querySelectorAll(".li1")[-self.pos];
                var selectLi=li.querySelector(".selected");
                var selectObj=self.dateObj(self.options.selectDate);
                var y,m,d;
                if(selectLi){
                    li=selectLi;
                }
                var ymd=self.dateObj(li.getAttribute("data-ymd"));
                if(ymd[0]===selectObj[0]&&ymd[1]===selectObj[1]){
                    y=selectObj[0];
                    m=selectObj[1];
                    if(ymd[2] === selectObj[2]){
                        d=selectObj[2];
                    }else{
                        d=ymd[2];
                    }
                }else{
                    y=ymd[0];
                    m=ymd[1];
                    d=1;
                }
                self.refresh({
                    y:y,
                    m:m,
                    d:d
                });
                //if(that.options.uichangeToCallback){
                //
                //}
                self.callback(y,m,d);
                self.setTitle(y,m,d);
            }
            //切换视图按钮开启情况下
            if(self.options.switchViewBtn && self.show){
                cmp.event.click(self.show,function(){
                    if(self.options.type==="week"){
                        self.options.type="month";
                    }else if(self.options.type==="month"){
                        self.options.type="week";
                    }
                    typeChange();
                });
                var showMove = new Move(self.show,{
                    startFn:function(obj){
                        self.options.startH=self.box.offsetHeight;
                    },
                    moveFn:function(obj,isScrolling){
                        if(obj.scale) return;  //多个触摸点的时候禁止滑动
    
                        if(isScrolling === 1){
                            obj.events.preventDefault();  //阻止默认事件
                            var boxH=self.box.offsetHeight;
                            boxH+=obj.deltaY/3;
                            self.box.style["height"]=boxH+"px";
                        }
                    },
                    endFn:function(obj,isScrolling){
                        var boxH=self.box.offsetHeight;
                        self.box.style["height"]="auto";
                        if(self.options.type==="week" && boxH - self.options.startH > 5 ){
                            self.options.type="month";
                            typeChange();
                        }else if(self.options.type==="month" && boxH-self.options.startH < -5 ){
                            self.options.type="week";
                            typeChange();
                        }
                    }
                });
            }

            cmp.event.orientationChange(function (res) {
                self.refreshUI();
            });

        },
        //前进后退按钮集合事件处理
        switchBtnEvent:function(page){
            var self = this;
            var last=self.ele.querySelector(".ul_content").querySelectorAll(".li1")[page.indexOf("next")>-1?2:0];
            if(!last){
                last=self.ele.querySelector(".ul_content").querySelectorAll(".li1")[1];
            }
            var chooseData = self.dateObj(last.getAttribute("data-ymd"));
            if(page == "maxPrev"){//上一年分
                chooseData[0] = chooseData[0]-1;
                chooseData[1] = chooseData[1]==12 ? 1 : chooseData[1]+1;
            }else if(page == "maxnext"){ //下一年分
                var _thisDom = self.ele.querySelector(".ul_content").querySelectorAll(".li1")[1];
                var _thisYear = self.dateObj(_thisDom.getAttribute("data-ymd"));
                if(chooseData[0] < _thisYear[0] || chooseData[0] == _thisYear[0]){
                    chooseData[0] = chooseData[0]+1;
                }else{
                    chooseData[0] = chooseData[0];
                }
                chooseData[1] = chooseData[1] == 1 ? 12 : chooseData[1]-1;  
            }
            self.content.style[self._transition]="all 300ms";
            var movePos = page.indexOf("next")>-1 ? (self.pos-1)*self.boxW : 0;
            self.content.style[self._transform]="translate("+movePos+"px,0px) translateZ(0px)";
            setTimeout(function(){
                self.content.style[self._transition]="all 0ms";
                var nextDomSelected = last.querySelector("li.now");
                if(nextDomSelected){
                    self.options.selectDate = self.dateStr(self.options.y,self.options.m,self.options.d);
                }else{
                    self.options.selectDate = self.dateStr(chooseData[0],chooseData[1],1);
                }
                self.setTitle(chooseData[0],chooseData[1],1);
                self.monthRender(chooseData[0],chooseData[1]);
                self.callback(chooseData[0],chooseData[1],chooseData[2]);
            },300);
        },
        assemblyResult: function(y,m,d){
            var self = this;
            var selectedData;
            if(y != null && m != null && d != null){
                selectedData = self.dateStr(y,m,d);
            }
            var targetLi = self.content.querySelectorAll(".li1")[-self.pos];
            var dateLineUl = targetLi.querySelector("div.ul_dateBlock").querySelectorAll("ul.ul_dateLine");
            var beginLi = dateLineUl[0].firstChild;
            var lastLi = dateLineUl[dateLineUl.length-1].lastChild;
            var beginymd = self.dateObj(beginLi.getAttribute("data-ymd"));
            var endymd = self.dateObj(lastLi.getAttribute("data-ymd"));

            return {
                y:y,
                m:m,
                d:d,
                type:self.options.type,
                by:beginymd[0],
                bm:beginymd[1],
                bd:beginymd[2],
                ey:endymd[0],
                em:endymd[1],
                ed:endymd[2],

                value:selectedData
            };
        }


    };

    
    cmp.DateCalender= function(ele,options){
        return new DateCalender(ele,options);
    };
})(cmp);



