 
/**
 * CMP新增组合搜索插件
 * -mashan
 */

 /**
 * @module cmp
 */
 /**
 * @method groupSearch
 * @requireJS ["cmp-groupSearch.js"]
 * @description 组合搜索组件 cmp.groupSearch.init(selector,options)
 * @createDate 2019-07-30
 * @lastModify 2019-08-14
 * @param {string} selector 调用搜索组件的容器id 可穿个""或者null
 * @param {object} options 配置 
 * @param {Array} options.items 按照哪些类型来搜索 
 * @paramTemplate options.items 最多传三个选择类型
 * @param {string} options.items[0].id 自定义id  <isNotNull>
 * @param {string} options.items[0].type 需要显示什么类型 
 * @paramTemplate options.items[0].type 1.text：文本 2.date：开始和结束时间选择类型
 * @param {string} options.items[0].text 标题
 * @param {string} options.items[0].condition 自定义参数，值根据自己业务随便传  <isNotNull>
 * @param {string} options.appId 当前应用的appId，传了此参数意味着根据当前应用显示搜索记录  <isNotNull>
 * @param {object} options.dateOptions 时间选择自定义  <isNotNull>
 * @paramTemplate options.dateOptions 可自定义成日历显示样式或者滚动显示样式的时间选择，默认值：{"type": "date", "MinutesScale": '1'}
 * @param {boolean} options.openSearchResult 是否显示搜索结果容器 默认true 显示  <isNotNull>
 * @param {boolean} options.H5Header 是否显示H5的头部 默认true 显示  <isNotNull>
 * @param {function} options.callback 点击确定按钮回调  <isNotNull>
 * @param {function} options.closeCallback 关闭组件回调  <isNotNull>
 * 
 */


(function (_) {
    var CMP_GROUPSEARCH_I18N_LOADED = false;
    _.i18n.load(cmpBASEPATH+'/i18n/', 'cmp-search',function(){
        CMP_GROUPSEARCH_I18N_LOADED = true;
        _.event.trigger("cmp-groupSearch-init",document);
    },cmpBuildversion);

    /*** 常用的搜索组件，提供两种类型搜索的切换：<br>*/
    _.groupSearch = {};
    /*** 搜索组件的调用方法(标准版)*/
    _.groupSearch.init = function (selector, options) {
        return groupSearch(selector,options);
    };
    /*** 搜索组件的关闭方法*/
    _.groupSearch.init_close = function () {
        if (_groupSearch) {
            _groupSearch.destroy();
            // _groupSearch = null;
        }
    };

    
    function groupSearch(options) {
        if(!CMP_GROUPSEARCH_I18N_LOADED){
            document.addEventListener("cmp-groupSearch-init",function(){
                _groupSearch.init(options);
            });
        }else {
            _groupSearch.init(options);
        }
    }

    var _groupSearch = {

        init:function(options){
            var self = this;
            self.opts = _.extend({
                id: '',
                model: {
                    name: "coordination",
                    id: "888888"
                },
                items: options.items ||
                [
                    {id:"01",type: 'text',text: '标题',condition: 1},
                    {id:"02",type: 'text',text: '发起人',condition: 2},
                    {id:"03",type: 'date',text: '创建时间',condition: 3},
                    {id:"04",type: 'custom',text: '自定义',condition: 4,html:""}
                ],
                appId:options.appId || "",  //各应用下的搜索历史，根据appId来记录。
                dateOptions: options.dateOptions || {"type": "dateCalender", "MinutesScale": '1'},
                openSearchResult:options.openSearchResult || true,
                controlNewTime:options.controlNewTime || false, //是否控制开始时间不能小于当前时间，默认false不控制
                controlTime:options.controlTime || true,//是否控制开始时间不能小于当前时间和结束时间。true:控制(默认),false:不控制
                H5Header:options.H5Header || false,//是否显示h5头部
                callback: options.callback || null,
                closeCallback:options.closeCallback || null//关闭组件回调
            }, options);
            self.controlNewTime = self.opts.controlNewTime;
            self.controlTime = self.opts.controlTime;
            self.isH5head = self.opts.H5Header;
            self.appId = self.opts.appId;
            self.dateType = self.opts.dateOptions.type;
            _.backbutton.push(_.groupSearch.init_close);
            self._initDom();
            self.gethistory(self.appId);
            self._bindEvent();
        },


        initTpl:function(){
            var self = this;
            var str = '';
            if(self.isH5head){
                str += '<header class="cmp-bar cmp-bar-nav cmp-flex-header">'+
                '<div class="cmp-header-left searchBack">'+
                    '<span class="cmp-icon see-icon-v5-common-arrow-back"></span>'+
                    '<span class="nav-text">'+_.i18n("cmp.search.back")+'</span>'+
                '</div>'+
                '<div class="cmp-title">'+
                    '<span>'+_.i18n("cmp.search.SearchResult")+'</span>'+
                '</div>'+
                '<div class="cmp-header-right">'+
                    // '<span class="cmp-icon see-icon-add-round"></span>'+
                '</div>'+
                '</header>';
                str +='<div class="cmp-content position_relative cmp-white-bg" id="search_container">';
            }else{
                str +='<div class="position_relative cmp-white-bg" style="top:0!important;" id="search_container">';
            }
            str +='<div class="search-content" id="conditionContent"></div>';
            //历史记录容器
            str +='<div class="cmp-groupSearch-history flex"></div>';
            str +='<div class="title_submit cmp-white-bg">'+
                        '<button class="resetBtn cmp-badge cmp-badge-primary cmp-border-c2 cmp-theme-fc cmp-white-bg custom">'+_.i18n("cmp.search.Reset")+'</button>'+
                        '<button class="submitBtn cmp-badge cmp-badge-purple cmp-border-c2 cmp-button-bgc">'+_.i18n("cmp.search.ok")+'</button>'+
                    '</div>';
            str += '</div>';
            return str;
        },

        //初始化html结构
        _initDom : function () {
            var self = this;
            self.wrapper = document.createElement('div');
            self.wrapper.className = "Animated-Container right-go animated cmp-searchInit cmp-groupSearch cmp-active";
            
            self.wrapper.innerHTML = self.initTpl();

            self.wrapper.style.backgroundColor = "rgba(0, 0, 0, 0.31)";
            self.wrapper.style.height = CMPFULLSREENHEIGHT +'px';
            document.body.appendChild(self.wrapper);
    
            self.resetBtn = self.wrapper.querySelector('.resetBtn');
            self.submitBtn = self.wrapper.querySelector('.submitBtn');
            self.conditionContent = self.wrapper.querySelector("#conditionContent");
            self.conditionContent.appendChild(self._initConditionUI());
            self.searchCellDom = self.conditionContent.querySelectorAll('.cmp-search-cell');
            self.selectDom = self.conditionContent.querySelectorAll(".selectDom");
            self.timeGroup = self.conditionContent.querySelectorAll('.timeGroup');
            self.homeSearchBack = self.wrapper.querySelector('.searchBack');

            self.dtPicker=null;
            self.conditionData = {};
            self.openSearchResult = self.opts.openSearchResult;
            var backDrapDiv = document.createElement("div");
            backDrapDiv.className = "group-backdrop";
            self.wrapper.appendChild(backDrapDiv);
            self.backDrapDiv = backDrapDiv;
        },
        // 初始化搜索条件集合--返回搜索条件UI
        _initConditionUI : function(){
            var self = this;
            var getItems = self.opts.items;
            var conditionDom = document.createElement("div");
            conditionDom.className = "cmp-search-content cmp-white-bg";
            if(getItems && getItems.length > 0){
                for(var i=0,len=getItems.length;i<len;i++){
                    var itemData = getItems[i];
                    var itemHtml = "";
                    var itemBox = document.createElement("div");
                    itemBox.className ="cmp-search-cell flex cmp-input-bg";
                    itemBox.setAttribute("type",itemData.type);
                    itemBox.setAttribute("condition",itemData.condition);
                    itemBox.setAttribute("id",itemData.id);
                    if(itemData.html){
                        itemBox.setAttribute("ishtml",true);
                    }
                    var defValue = itemData.defValue || "";
                    
                    if(itemData.type == "text"){ //文本类型
                        var defualtValue = defValue ? defValue : _.i18n("cmp.search.entry")+itemData.condition;
                        itemHtml +='<div class="title_name cmp-ellipsis cmp-f-4 cmp-main-fc cmp-after-line">'+itemData.text+'</div>'+
                        '<div class="title_dom flex1"><input type="text" value="'+defValue+'" def="'+defValue+'" class="input cmp-input-bg cmp-cont-fc" placeholder="'+_.i18n("cmp.search.entry")+itemData.condition+'">'+
                        '</div>';
                    }else if(itemData.type == "date"){
                        var startTime = "",endTime="";
                        if(defValue && defValue instanceof Array && defValue.length > 0 ){
                            startTime = defValue[0];
                            if(defValue.length > 1 ){
                                endTime = defValue[1];
                            }
                            if(defValue[0]!="" || defValue[1]!=""){
                                defValue = defValue.toString();     
                            }else{
                                defValue = "";
                            }
                        }else{
                            startTime = defValue;
                        }
                        // startTime = self.currentTime();
                        // endTime = self.currentTime();
                        itemHtml +='<div class="title_name cmp-ellipsis cmp-f-4 cmp-main-fc cmp-after-line">'+itemData.text+'</div>'+
                        '<div class="title_dom flex1">';
                        
                        // if(defValue){ //是否有年月日的默认数据
                        //     if(defValue instanceof Array && self.dateType == "dateTimeCalender"){
                        //         defValue = defValue.toString();
                        //     }
                        // }
                        itemHtml +='<div class="timeGroup flex" defValue="'+defValue+'" >'+
                        '<div class="inputTime startTime cmp-input-bg cmp-cont-fc flex1">'+startTime +'</div>'+
                        '<div class="line cmp-liactive-bgc"></div>'+
                        '<div class="inputTime endTime cmp-input-bg cmp-cont-fc flex1">'+endTime +'</div>'+
                        '</div>';
                        itemHtml +='</div>';
                    }else if(itemData.type == "select"){
                        var defualtValue = defValue ? JSON.stringify(defValue).escapeHTML() : _.i18n("cmp.search.entry")+itemData.condition;
                        var defText = defValue.text;
                        var defValue = defValue.value;
                        var options = JSON.stringify(itemData.options).escapeHTML();
                        itemHtml +='<div class="title_name cmp-ellipsis cmp-f-4 cmp-main-fc cmp-after-line">'+itemData.text+'</div>'+
                        '<div class="title_dom selectDom cmp-input-bg" self_options="'+options+'">'+
                            '<div class="select_value cmp-input-bg cmp-main-fc" defValue="'+defualtValue+'" text="'+defText+'" value="'+defValue+'">'+defText+'</div>'+
                            '<div class="select_arrow see-icon-v5-common-arrow-plane-down"></div>'+
                        '</div>';
                    }else if(itemData.type == "custom"){
                        itemHtml +='<div class="title_name cmp-ellipsis cmp-f-4 cmp-main-fc cmp-after-line">'+itemData.text+'</div>'+
                        '<div class="title_dom">'+(itemData.html ||"")+'</div>';
                    }
                    itemBox.innerHTML = itemHtml;
                    conditionDom.appendChild(itemBox);
                }
                return conditionDom;
            }else {
                return "";
            }
            
        },
        
        
        saveHistory:function(appId,params,call){
            var url = cmp.util.getSeeyonPath() + '/rest/searchHistory/add';
            var param = {
                "category": appId ,  //模块ID 协同、公文等。
                "acctionID":1,  //搜索类型ID,比如已发，待办等。
                "searchTypeList":params   //searchTypeList
            }
            cmp.ajax({
                type:"POST",
                url:url,
                data:JSON.stringify(param),
                success:function(res){
                    console.log(res)
                    call && call(res)
                },
                error:function(res){
                    console.log(res)
                    call && call(res)
                }
            });
        },

        gethistory:function(appId){
            if(!appId)return;
            var self = this;
            var url = cmp.util.getSeeyonPath() + '/rest/searchHistory/'+appId+'/1';
            cmp.ajax({
                type:"GET",
                url:url,
                success:function(res){
                    console.log(res);
                    self.renderHistory(res);
                },
                error:function(res){
                    console.log(res)
                }
            });
        },
        //渲染历史记录
        renderHistory:function(result){
            var self = this;
            var str = '';
            var item = result.data;
            var historyContent = self.wrapper.querySelector(".cmp-groupSearch-history");
            var newArrayValue = {};
            if(item && item.length >0 ){
                str +='<div class="cmp-groupSearch-txt cmp-sup-fc2">'+_.i18n("cmp.search.history2")+':</div><ul class="cmp-groupSearch-ul">';
                for(var i=0,len=item.length;i<len;i++){
                    var cell = item[i].searchTypeList;
                    for(var j=0,jlen=cell.length;j<jlen;j++){
                        var obj = cell[j];
                        var info = {
                            conditionType:obj.conditionType,
                            type:obj.searchKeyType,//文本还是时间类型
                            domId:obj.conditionType,  //容器ID
                            value:obj.param1   //记录值
                        }
                        if(!info.value || (info.value.indexOf("undefined")>-1) ){
                            continue;
                        }
                        if(newArrayValue[info.value] == "true" ){
                            break;
                        }
                        str +='<li class="cmp-groupSearch-li cmp-f-4 cmp-tapsup-fc cmp-ellipsis" info="'+JSON.stringify(info).escapeHTML()+'">'+(info.value||"")+'</li>';
                        
                        newArrayValue[info.value]="true";
                    }
                }
                str +='</ul>';
                str +='<div class="cmp-groupSearch-del"><span class="cmp-groupSearch-delIcon see-icon-v5-common-delete cmp-sup-fc2"></span></div>';
                historyContent.innerHTML = str;
            }
            //点击每条历史记录
            $cmp(".cmp-groupSearch-li").on("tap",function(){
                var info = JSON.parse(this.getAttribute("info"));
                var domId = info.domId;
                var type = info.type;
                var value = info.value;
                var conditionType = info.conditionType;
                var lis = historyContent.querySelectorAll(".cmp-groupSearch-li");
                for(var i=0,len=lis.length;i<len;i++){
                    var item = lis[i];
                    var info = JSON.parse(item.getAttribute("info"));
                    if(item.classList.contains("active") && info.conditionType == conditionType ){
                        item.classList.remove("active");
                    }
                }
                $cmp(this).addClass("active");
                if(type == "1"){  //文本类型
                    $cmp("#"+domId).find("input").val(value);
                }else if(type == "2"){  //时间类型
                    var startDom = $cmp("#"+domId).find(".startTime");
                    var endDom = $cmp("#"+domId).find(".endTime");
                    var timeValue = value.split(",");
                    startDom.text(timeValue[0]);
                    endDom.text(timeValue[1]);
                }
            });
            //点击历史记录删除删除按钮
            $cmp(".cmp-groupSearch-del").on("tap",function(){
                cmp.notification.confirm(_.i18n("cmp.search.delAll"),function(index){
                    if(index == 1){
                        historyContent.innerHTML = "";
                        self.delHistory(self.appId);
                    }
                });
            });
        },
        //删除历史记录
        delHistory:function(appId,call){
            var url = cmp.util.getSeeyonPath() +'/rest/searchHistory/del/'+appId+'/1';
            cmp.ajax({
                type:"POST",
                url:url,
                success:function(res){
                    console.log(res)
                    call && call(res);
                    // cmp.notification.toast("刪除成功!");
                },
                error:function(res){
                    console.log(res)
                    call && call(res);
                    // cmp.notification.toast("刪除失敗!");
                }
            });
        },
        _bindEvent : function(){
            var self = this;
            //点击重置按钮
            _.event.click(self.resetBtn,function(){
                self.doBtn(false);
            });
            //点击确定按钮
            _.event.click(self.submitBtn,function(){
                var resultObj = {};
                var result = self.doBtn(true);

                var resultFun = function(){
                    if(self.openSearchResult){
                        var controlContent = self.openSearchContent();
                        resultObj = {
                            controlContent:controlContent,
                            result:result
                        }
                        self.opts.callback && self.opts.callback(resultObj);
                    }else{
                        resultObj = {
                            controlContent:null,
                            result:result
                        }
                        self.opts.callback && self.opts.callback(resultObj);
                        self.destroy();//销毁
                    }
                }
                var isMarkValue=false;
                if(self.appId){ //传递了应用ID的话，需要执行搜索记录接口
                    var newArray = [];
                    for(var i=0,len=result.length;i<len;i++){
                        var item = result[i];
                        var searchKeyType,searchValue;
                        if(item.type == "text"){  //文本类型
                            searchKeyType = 1;
                            searchValue = item.value;
                        }else if(item.type =="date"){ //时间类型
                            searchKeyType = 2;
                            if(self.getType(item.value) == "[object Array]"){
                                searchValue = item.value[0] + "," +item.value[1];
                            }else{
                                searchValue = item.value;
                            }
                            
                        }
                        var obj = {
                            "searchKeyType": searchKeyType ,  //搜索条件类型，文本、时间等  1、文本 2、时间。
                            "conditionType": item.id ,  //条件类型 标题/发起人/时间段，开始或者结束时间等。
                            "param1":searchValue
                        }
                        if(searchValue){
                            isMarkValue = true;
                        }
                        if(searchValue =="undefined:undefined"){
                            isMarkValue = false;
                        }
                        newArray.push(obj);
                    }
                    if(isMarkValue){
                        self.saveHistory(self.appId,newArray,function(res){
                            console.log(res);
                            resultFun();
                        });
                    }else{
                        resultFun();
                    }
                }else{
                    resultFun();
                }
            });
            //给input元素执行监听
            var inputs = self.conditionContent.querySelectorAll("input.input");
            if(inputs && inputs.length>0){
                for(var inp=0,inpLen=inputs.length;inp<inpLen;inp++){
                    var inputItem = inputs[inp];
                    inputItem.addEventListener("input",function(){
                        this.setAttribute("value",this.value);
                    },false);
                }
            }
            //如果有select类型，将对select类型做点击事件
            if(self.selectDom && self.selectDom.length>0){
                for(var i=0,len=self.selectDom.length;i<len;i++){
                    _.event.click(self.selectDom[i],function(e){
                        e.stopPropagation();
                        e.preventDefault();
                        var parentDom = e.target.parentNode;
                        var options = JSON.parse(parentDom.getAttribute("self_options"));
                        var select_value;
                        if(e.target.classList.contains("select_value")){
                            select_value = e.target;
                        }else{
                            select_value = parentDom.querySelector('.select_value');
                        }
                        var pickerdefValue = select_value.getAttribute("text");
                        var selfPicker = new _.PopPicker({
                            data:options,
                            defualtValue:pickerdefValue
                        });
                        selfPicker.show(function(res){
                            console.log("select:"+JSON.stringify(res));
                            var value = res[0].text;
                            var select_value = parentDom.querySelector('.select_value');
                            select_value.setAttribute("text",value);
                            select_value.setAttribute("value",res[0].value);
                            select_value.innerHTML = value;
                            selfPicker.dispose();
                        });
                    });
                }
            }
            // 如果有时间选择类型，将对时间选择做点击事件监听
            if(self.timeGroup && self.timeGroup.length>0){
                for(var j=0,jlen=self.timeGroup.length;j<jlen;j++){
                    _.event.click(self.timeGroup[j],function(e){
                        var target = e.target;
                        if(!target.classList.contains('timeGroup')){
                            var parent = target.parentNode;
                            if(parent.classList.contains("timeGroup")){
                                target = parent;
                            }else{
                                return;
                            }
                        }
                        var selStartDom = target.querySelector('.startTime');
                        var selEndDom = target.querySelector('.endTime');
                        var defValue = target.getAttribute("defValue"); //节点上面的年月日
                        var startTime = "",endTime="";
                        var valueArray="";
                        
                        var options = {
                            type:"dateCalender",
                            value:defValue,
                            endValue:valueArray[1],
                            defTimeValue:[startTime,endTime],
                            group:true
                        };

                        if(defValue){
                            var dataSplit = defValue.split(",");
                            if(dataSplit){ //数组类型，证明是组合选择
                                if(dataSplit[0] && dataSplit[1]){
                                    if(dataSplit[0].split(" ")[0] && dataSplit[1].split(" ")[0] ){
                                        defValue = [dataSplit[0].split(" ")[0],dataSplit[1].split(" ")[0]];//年月日
                                        startTime = dataSplit[0].split(" ")[1] ||""; //开始时分
                                        endTime = dataSplit[1].split(" ")[1] ||"";  //结束时分
                                        options.value = defValue[0];
                                        options.endValue = defValue[1];
                                        options.defTimeValue = [startTime,endTime];
                                    }
                                }
                            }
                        }else{
                            if(self.dateType =="dateTimeCalender" || self.dateType =="dateCalender"){
                                options.endValue = self.currentTime();
                            }
                            options.value = self.currentTime();
                        }
                        
                        options = _.extend(options,self.opts.dateOptions);
                        var picker = new cmp.DtPicker(options);
                        picker.show(function(res){
                            console.log(res);
                            var startTimeValue="",startTimeValue="",endTimeValue="",beginTimes="",endTimes="";
                            if(self.dateType == "dateCalender" || self.dateType =="dateTimeCalender"){
                                startTimeValue = res.beginData && res.beginData.value || "";
                                endTimeValue = res.endData && res.endData.value || "";
                                beginTimes = res.beginTime || "";
                                endTimes = res.endTime || "";
                            }else{
                                startTimeValue = res.value;
                            }
                            if(beginTimes && endTimes){
                                startTimeValue = startTimeValue +" "+beginTimes;
                                endTimeValue = endTimeValue +" "+endTimes;
                            }
                            var startTime = new Date(startTimeValue.replace(/-/g, "/")).getTime()||"";
                            var endTime = new Date(endTimeValue.replace(/-/g, "/")).getTime()||"";
                            var newDate = new Date(),newTime=newDate.getTime();
                            if(self.controlNewTime){ //是否控制开始时间不能小于当前时间
                                if( startTime < newTime){  //开始时间小于当前时间的话
                                    _.notification.toast(_.i18n("cmp.search.startTimeNolessNewtime"), "center");
                                    return;
                                }
                            }
                            if(self.controlTime){  //是否控制开始时间不能大于结束时间
                                if( ( endTime != newTime ) && (startTime > endTime )){ //开始时间大于结束时间
                                    _.notification.toast(_.i18n("cmp.search.warningMsgStart"), "center");
                                    return;
                                }
                            }
                            var newDefValue="";
                            if(self.dateType == "dateCalender" || self.dateType =="dateTimeCalender"){
                                newDefValue = [startTimeValue,endTimeValue].toString();
                            }else{
                                newDefValue = startTimeValue;
                            }
                            target.setAttribute("defValue",newDefValue);
                            selStartDom.innerHTML = startTimeValue;
                            selEndDom.innerHTML = endTimeValue;
                        });
                        // cmp.groupTime.init(options);;
                        // self.getTime(options);
                    });
                }
                
            }
            //点击返回按钮
            if(self.homeSearchBack){
                _.event.click(self.homeSearchBack,function(){
                    self.destroy();
                });
            }
            //点击背景
            if(self.backDrapDiv){
                _.event.click(self.backDrapDiv,function(){
                    self.destroy();
                });
            }
           
        },
        //执行的重置和确定按钮集合
        doBtn : function(isSubmit){
            var self = this;
            var result=[];
            for(var i=0,len=self.searchCellDom.length;i<len;i++){
                var itemDom = self.searchCellDom[i];
                var title_dom = itemDom.querySelector(".title_dom");
                var type = itemDom.getAttribute("type");
                var _input = title_dom.querySelector("input");
                var startTime = title_dom.querySelector('.startTime');
                var endTime = title_dom.querySelector('.endTime');

                var selectDom = itemDom.querySelector('.selectDom');
                if(isSubmit){ //点击确定按钮
                    var condition = itemDom.getAttribute("condition");
                    var id = itemDom.getAttribute("id");
                    var value="";
                    if(type == "date"){
                        var startTime = startTime.innerText;
                        var endTime = endTime.innerText;
                        
                        if(startTime && endTime ){
                            value = [startTime,endTime];
                        }else if(startTime){
                            value = startTime;
                        }
                        
                    }else if(type =="select"){
                        var select_value = selectDom.querySelector('.select_value');
                        value = {
                            value:select_value.getAttribute("value"),
                            text:select_value.getAttribute("text")
                        };
                    }else{
                        if(_input){
                            value = _input.value=="" && _input.getAttribute("value")=="" ? "" : _input.value;
                            
                        }else{
                            value =  title_dom.innerHTML;
                        }
                        // value = _input ? _input.value?_input.value:_input.getAttribute("value")?_input.getAttribute("value"):_input.getAttribute("def") : title_dom.innerHTML;
                    }
                    var obj = {id:id, type:type, condition:condition,value:value };
                    result.push(obj);
                }else{ //点击重置
                    var groupSearchUl = self.wrapper.querySelector(".cmp-groupSearch-ul");
                    if(groupSearchUl){
                        var groupSearchLi = groupSearchUl.querySelectorAll(".cmp-groupSearch-li");
                        for(var j=0,jlen=groupSearchLi.length;j<jlen;j++){
                            var item = groupSearchLi[j];
                            item.classList.remove("active");
                        }
                    }
                    if(type == "date"){
                        var timeGroup = title_dom.querySelector('.timeGroup');
                        // var selfTime = JSON.parse(timeGroup.getAttribute("defValue"));
                        // startTime.innerHTML = selfTime&&selfTime.length>0?selfTime[0]:self.currentTime();
                        // endTime.innerHTML = selfTime&&selfTime.length>1?selfTime[1]:self.currentTime();
                        startTime.innerHTML = "";endTime.innerHTML = "";
                        timeGroup.setAttribute("defvalue","");
                    }else if(type == "select"){
                        var select_value = selectDom.querySelector('.select_value');
                        var defValue = JSON.parse(select_value.getAttribute("defvalue"));
                        select_value.setAttribute("text",defValue.text);
                        select_value.setAttribute("value",defValue.value);
                        select_value.innerHTML = defValue.text;
                    }else if(type == "text"){
                        var condition = itemDom.getAttribute("condition");
                        if(_input){
                            _input.setAttribute("value","");
                            _input.setAttribute("def","");
                            _input.setAttribute("placeholder",_.i18n("cmp.search.entry")+condition);
                            _input.value="";
                        }
                    }else{
                        if(_input)_input.value="";
                    }
                    
                }
            }
            if(isSubmit){
                // _.backbutton.pop();
                return result;
            }
        },
        //获取当前时间
        currentTime : function(){
            var self = this;
            var NewDate = new Date();
            var Year = NewDate.getFullYear();
            var Month = NewDate.getMonth() + 1;
            var Day = NewDate.getDate();
            Month = Month < 10 ? '0' + Month : Month;
            Day = Day < 10 ? '0' + Day : Day;
            var Time = Year + '-' + Month + '-' + Day;
            return Time;
        },
        //打开搜索结果容器
        openSearchContent : function(){
            var self = this;
            // 搜索结果容器
            self.headerDom = '<header class="cmp-bar cmp-bar-nav cmp-flex-header">'+
                '<div class="cmp-header-left searchBack">'+
                    '<span class="cmp-icon see-icon-v5-common-arrow-back"></span>'+
                    '<span class="nav-text">'+_.i18n("cmp.search.back")+'</span>'+
                '</div>'+
                '<div class="cmp-title">'+
                    '<span>'+_.i18n("cmp.search.SearchResult")+'</span>'+
                '</div>'+
                '<div class="cmp-header-right">'+
                    // '<span class="cmp-icon see-icon-add-round"></span>'+
                '</div>'+
            '</header>';
            var cmpContent = self.opts.H5Header?"cmp-content":"";
            self.searchResultContent = '<div class=" '+cmpContent+' position_relative">'+
                '<div class="controlContent"></div>'+
            '</div>';

            var SearchContent = document.createElement('div');
            SearchContent.className = "Animated-Container right-go animated cmp-searchDefualt cmp-active";
            if(self.opts.H5Header){
                SearchContent.innerHTML = self.headerDom + self.searchResultContent;
            }else{
                SearchContent.innerHTML = self.searchResultContent;
            }
            SearchContent.style.zIndex = 86;
            SearchContent.style.height = CMPFULLSREENHEIGHT +'px';
            document.body.appendChild(SearchContent);
            var headerBack = SearchContent.querySelector('.searchBack');
            var controlContent = SearchContent.querySelector('.controlContent');
            var headerDom = SearchContent.querySelector('header');
            controlContent.style.height = CMPFULLSREENHEIGHT - (headerDom?headerDom.offsetHeight:0) +"px";
            if(headerBack){
                _.event.click(headerBack,function(){
                    SearchContent.classList.remove('cmp-active');
                    SearchContent.remove();
                    _.backbutton.pop();
                });
            }
            
            // _.backbutton.push(function(){
            //     SearchContent.classList.remove('cmp-active');
            //     SearchContent.remove();
            //     SearchContent = null;
            // });
            return controlContent;
        },
        //组件销毁
        destroy : function(){
            var self = this;
            self.wrapper.classList.remove('cmp-active');
            self.wrapper.remove();
            _.backbutton.pop();
            self = null;
        },
        //获取数据类型
        getType: function(data) {
            return Object.prototype.toString.call(data);
        },



    }



})(cmp);