(function(_){
    /**
     * 语音机器人设置，用于小致内部/平台方面的一些使用
     * @type {{}}
     * @author by guojl
     */
    _.speechRobot = {};

    //************************开关**************************

    var _setRobotOnOffState = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "setRobotOnOffState",
            [{
                isOnOff:options.isOnOff
            }]
        );
    };

    /**
     * 打开机器人
     * options 成功失败回调
    */
    _.speechRobot.open = function(options) {
        var _options =_.extend({isOnOff:true},options);
        _setRobotOnOffState(_options);
    };

    /**
     * 关闭机器人
     * options 成功失败回调
    */
    _.speechRobot.close = function(options) {
        var _options =_.extend({isOnOff:false},options);
        _setRobotOnOffState(_options);
    };


    /**
     * 获取机器人开关状态
     * options 成功失败回调 返回值res为 true false
    */
    _.speechRobot.getRobotOnOffState = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    var val = res.isOnOff;
                    if (typeof val == "string"){
                        val = val == "true";
                    }
                    options.success(val);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "getRobotOnOffState",
            [{}]
        );
    };
    

    //*************************语音按钮*************************


    var _setRobotAssistiveTouchOnShowState = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "setRobotAssistiveTouchOnShowState",
            [{
                isOnShow:options.isOnShow
            }]
        );
    };


    /**
     * 打开机器人语音按钮
     * options 成功失败回调
    */
    _.speechRobot.openAssistiveTouch = function(options) {
        var _options =_.extend({isOnShow:true},options);
        _setRobotAssistiveTouchOnShowState(_options);
    };

    /**
     * 关闭机器人语音按钮
     * options 成功失败回调
    */
    _.speechRobot.closeAssistiveTouch = function(options) {
        var _options =_.extend({isOnShow:false},options);
        _setRobotAssistiveTouchOnShowState(_options);
    };


    /**
     * 获取机器人语音按钮开关状态
     * options 成功失败回调 返回值res为 true false
    */
    _.speechRobot.getAssistiveTouchState = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    var val = res.isOnShow;
                    if (typeof val == "string"){
                        val = val == "true";
                    }
                    options.success(val);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "getRobotAssistiveTouchOnShowState",
            [{}]
        );
    };


    //************************自动唤醒**************************


    var _setRobotAutoAwakeState = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "setRobotAutoAwakeState",
            [{
                isAutoAwake:options.isAutoAwake
            }]
        );
    };


    /**
     * 打开机器人自动唤醒
     * options 成功失败回调
    */
    _.speechRobot.openAutoAwake = function(options) {
        var _options =_.extend({isAutoAwake:true},options);
        _setRobotAutoAwakeState(_options);
    };


    /**
     * 关闭机器人自动唤醒
     * options 成功失败回调
    */
    _.speechRobot.closeAutoAwake = function(options) {
        var _options =_.extend({isAutoAwake:false},options);
        _setRobotAutoAwakeState(_options);
    };

    /**
     * 获取机器人自动唤醒开关状态
     * options 成功失败回调 返回值res为 true false
    */
    _.speechRobot.getAutoAwakeState = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    var val = res.isAutoAwake;
                    if (typeof val == "string"){
                        val = val == "true";
                    }
                    options.success(val);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "getRobotAutoAwakeState",
            [{}]
        );
    };


    //************************激活时间**************************

    /**
     * 设置机器人激活时间
     * options {startTime:xx,endTime:xx}
    */
    _.speechRobot.setRobotWorkTime = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "setRobotWorkTime",
            [{
                startTime:options.startTime,
                endTime:options.endTime
            }]
        );
    };

    /**
     * 获取机器人激活时间
     * 返回值 {startTime:xx,endTime:xx}
    */
    _.speechRobot.getRobotWorkTime = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "getRobotWorkTime",
            [{}]
        );
    };

    //*****************************************************

    /**
     * 获取机器人所以配置
     * 返回值 {isOnOff:xxx,isOnShow:xxx,isAutoAwake:xxx,startTime:xx,endTime:xx}
     */
    _.speechRobot.getRobotConfig = function(options) {
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "getRobotConfig",
            [{}]
        );
    };

    /**
     * 控制显示和隐藏小致图标,有些页面不需要显示
     * @param showOrNot 显示还是隐藏
     * @param options 回调等
     */
    _.speechRobot.toggleShowAssistiveTouchOnPageSwitch = function (showOrNot,options) {
        cordova.exec(
            function success(res){
                if(options && typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(options && typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "toggleShowAssistiveTouchOnPageSwitch",
            [{
                showOrNot:showOrNot
            }]
        );
    };

    //检查小智权限
    _.speechRobot.checkPermission = function(options){
        var _options = _.extend({
            success:null,
            error:null
        },options);
        cordova.exec(
             _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "checkXiaoZhiPermission",
            [{}]
        );
    };
    //获取语音输入内容（用于小致平台参数获取）
    _.speechRobot.getSpeechInput = function(options){
        var _options = _.extend({
            success:null,
            error:null
        },options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "getSpeechInput",
            [{}]
        );
    };

    //设置智能消息开关
    _.speechRobot.setMessageSwitch = function(options){
        cordova.exec(
            function success(res){
                if(typeof options.success == "function"){
                    options.success(res);
                }
            },
            function error(error){
                if(typeof options.error == "function"){
                    options.error(error);
                }
            },
            "CMPSpeechRobotConfigPlugin",
            "setMessageSwitch",
            [{
                mainSwitch:options.mainSwitch,//总开关
                cultureSwitch:options.cultureSwitch,//文化信息开关
                statisticsSwitch:options.statisticsSwitch,//统计数据开关
                arrangeSwitch:options.arrangeSwitch,//工作任务开关
                chartSwitch:options.chartSwitch//报表数据开关
            }]
        );
    };


    //打开页面（用于小致平台从小致的卡片H5页面打开应用的H5页面）
    _.speechRobot.openPage = function(options){
        var _options = _.extend({
            url:"",//加载的地址
            params:{},//传递的参数
            accessUrl:"http://xiaoz.v5.cmp/v/html/xiaoz-app-access.html",//中转界面Url moren
            success:null,
            error:null
        },options);
        //转换一下，原生只缓存params整个，H5开发在传参的时候符合cmp.href.next的模式
        _options.params = {
            url:_options.url,
            accessUrl:_options.accessUrl,
            params:_options.params
        };
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "openPage",
            [_options]
        );
    };

    //小致语音播报（小致平台中H5卡片语音播报）
    _.speechRobot.broadcast = function(options){
        var _options = _.extend({
            text:"",//需要被播报的文字
            success:null,
            error:null
        },options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "broadcast",
            [_options]
        );
    };
    /**
     * 可选项卡片：设置选中的选项对当前意图
     */
    _.speechRobot.setOptionValue = function (options) {
        var _options = _.extend({
            data:{},//传递的参数
            message:"",//显示的文本
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "setOptionValue",
            [{
                "data":_options.data,
                "message":_options.message
            }]
        );
    };
    /**
     * 可选项卡片：设置选中的选项对下一个意图
     */
    _.speechRobot.nextIntent = function (options) {
        var _options = _.extend({
            data:{},//传递的参数
            message:"",//显示的文本
            nextIntent:"",//下一个意图
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "nextIntent",
            [{
                "data":_options.data,
                "nextIntent":_options.nextIntent,
                "message":_options.message
            }]
        );
    };
    /**
     * 可选项卡片：设置选择命令词
     * @param options 配置参数，数组形式，一个key对应一组命令文字，比如用户说“预定”、“申请”都返回同一个key名字
     * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
     * error:错误回调，包括code和message
     */
    _.speechRobot.setOptionCommands = function (options) {
        var _options = _.extend({
            commands: {},//命令词
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "setOptionCommands",
            [_options.commands]
        );
    };
    // webview高度改变了
    _.speechRobot.webviewChangeHeight = function (options) {
        var _options = _.extend({
            height: "0",//改变的高度
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "webviewChangeHeight",
            [{"height":_options.height}]
        );
    };
    //h5传递文本给小致：如"取消"
    _.speechRobot.passOperationText = function (options) {
        var _options = _.extend({
            text: "",
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "passOperationText",
            [{"text":_options.text}]
        );
    };
    /**
     * 打开智能QA界面
     * @param options
     *  openType:打开类型，qaApp-打开智能QA，qaCategory-打开某个QA应用，qaInfo-打开某个应用下的问题分类 chatResponse-打开某个问题
     *  params: 参数
     *  pushView:0-不打开界面，1-打开界面
     * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
     * error:错误回调，包括code和message
     */
    //
    _.speechRobot.openQAPage = function (options) {
        var _options = _.extend({
            openType: "",
            params:{},
            pushView:"1",
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "openQAPage",
            [{
                "openType":_options.openType,
                "params":_options.params,
                "pushView":_options.pushView
            }]
        );
    };
    /**
     * 小致打开智能QA界面
     * @param options
     *  openType:打开类型，qaApp-打开智能QA，qaCategory-打开某个QA应用，qaInfo-打开某个应用下的问题分类 chatResponse-打开某个问题
     *  params: 参数
     *  pushView:0-不打开界面，1-打开界面
     * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
     * error:错误回调，包括code和message
     */
    _.speechRobot.xiaozOpenQAPage = function (options) {
        var _options = _.extend({
            openType: "",
            params:{},
            pushView:"1",
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            "CMPSpeechRobotConfigPlugin",
            "xiaozOpenQAPage",
            [{
                "openType":_options.openType,
                "params":_options.params,
                "pushView":_options.pushView
            }]
        );
    };
    /**
     * 获取QA关联应用权限
     * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
     * error:错误回调，包括code和message
     */
    _.speechRobot.getShortCutIds = function (options) {
        var _options = _.extend({
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            'CMPSpeechRobotConfigPlugin',
            'getShortCutIds',
            [{}]
        )
    };
    /**
     * 小致打开全文检索界面
     *question:问题内容
     * url 全文检索的url
     * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
     * error:错误回调，包括code和message
     */
    _.speechRobot.openAllSearchPage = function (options) {
        var _options = _.extend({
            question:'',
            url:'',
            success:null,
            error:null
        }, options);
        cordova.exec(
            _options.success,
            _options.error,
            'CMPSpeechRobotConfigPlugin',
            'openAllSearchPage',
            [{
                question:_options.question,
                url:_options.url
            }]
        )
    };

})(cmp);
