/**
 * 对外提供的组件
 */
;(function($) {
    $.i18n.load(cmpBASEPATH+'/i18n/', 'cmp-xiaozhi-sdk',null,cmpBuildversion);
    function sdk() {}

    sdk.prototype = {
        
        /**
         * @method syncExec
         * @param {string} service 类名
         * @param {string} action 方法名
         * @param {any} data 参数
         */
        syncExec: function(service, action, data) {
            if ($.os.android) {
                return window.CMPNativeBridge.smRequest(service, action, JSON.stringify(data));
            }
            var requestParams = {
                service:service,
                action:action,
                data:data
            };
            requestParams = JSON.stringify(requestParams);
            var xhr = new window.XMLHttpRequest();
            var url = "http://127.0.0.1/nativeservice";
            xhr.open("POST", url, false);
            xhr.send(requestParams);
            var nativeResult = xhr.responseText;
            return nativeResult;
        },

        /**
         * @method exec
         * @description 执行函数
         * @param {srting} plugin 类名
         * @param {string} action 方法名
         * @param {any} params 参数
         * @param {function} success 成功回调
         * @param {function} error 错误回调
         */
        exec: function (plugin, action, params, success, error) {
            cordova.exec(success || function () { },error || function () { }, plugin, action, [params]);
        },
        //人脸识别
        faceDetect:{
            //创建人脸数据
            create: function(options) {
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'create', {}, options.success, function error(e){
                    _handleSDKError(e,options.error);
                });
            },
            //更新人脸数据
            update: function(options) {
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'update', {}, options.success, function error(e){
                    _handleSDKError(e,options.error);
                });
            },
            //删除人脸数据
            remove: function(options) {
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'remove', {}, options.success, options.error);
            },
            //根据人脸获取用户id
            obtain: function(options) {
                var _options = cmp.extend({
                    params:{
                        live:false,
                        liveEnum:{
                            eye:false,//眨眼睛
                            mouth:false,//张嘴巴
                            headRight:false,//头向右转
                            headLeft:false,//头向左转
                            headUpward:false,//头向上抬
                            headDownward:false,//低头
                            headShake:false//摇头
                        }
                    },
                    success:function(){},
                    error:function(){}
                },options);
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'obtain', _options.params || {}, _options.success, function error(e){
                    _handleSDKError(e,_options.error);
                });
            },
            //检测人脸是否是本人
            check: function(options) {
                var _options = cmp.extend({
                    params:{
                        live:false,
                        liveEnum:{
                            eye:false,//眨眼睛
                            mouth:false,//张嘴巴
                            headRight:false,//头向右转
                            headLeft:false,//头向左转
                            headUpward:false,//头向上抬
                            headDownward:false,//低头
                            headShake:false//摇头
                        }
                    },
                    success:function(){},
                    error:function(){}
                },options);
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'check', _options.params || {}, _options.success, function error(e){
                    _handleSDKError(e,_options.error);
                });
            },
            //判断用户是否已经注册过了人脸数据
            registered: function(options) {
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'registered', {}, options.success, options.error);
            },
            //判断人脸组件是否用权限用
            hasPermission:function(options) {
                cmp.xiaozhi.exec('CMPFaceDetectPlugin', 'hasPermission', {}, options.success, options.error);
            }
        },

        //语音组件
        speech: {
            /**
             * 语音命令
             * @param options 配置参数，数组形式，一个key对应一组命令文字，比如用户说“同意”、“好的”都返回同一个key名字
             * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
             * error:错误回调，包括code和message
             */
            command: function (options) {
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'command', options.params || {}, options.success, function error(e) {
                    _handleSDKError(e, options.error);
                });
            },
            /**
             * 语音输入，输出文字
             * @param options
             * progress：语音输入过程中回调函数，返回语音文字内容（不是最终结果，是一段一段的文字）
             * success:语音输入完成回调函数，返回的语音文字内容（最终结果，最后一段文字）
             * error:错误回调，包括code和message
             */
            inputing: function (options) {
                var _options = cmp.extend({
                    params: {},
                    progress: function () {
                    },//中间输入过程的回调
                    success: function () {
                    },
                    error: function () {
                    }
                }, options);
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'inputing', _options.params, function (result) {
                    if (result.finish) {
                        _options.success(result);
                    } else {
                        _options.progress(result);
                    }

                }, function error(e) {
                    _handleSDKError(e, _options.error);

                });
            },
            /**
             * 语音转文字
             * @param options
             */
            transformText: function (options) {
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'transformText', options.params || {}, options.success, options.error);
            },
            /**
             * 语音播报(文字转语音)
             * @param options
             *          text：需要被转换的文字文本
             */
            broadcastText: function (options) {
                options = cmp.extend({
                    text: ""
                }, options);
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'broadcastText', options.text || {}, options.success, options.error);
            },
            /**
             * 停止语音播报
             * @param options
             */
            stopBroadcastText: function (options) {
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'stopBroadcastText', {}, options.success, options.error);
            },
            /**
             * 语音组件权限校验
             * @param options
             * success:result.success = true  表明有语音组件权限   false:没有语音组件权限
             * error:组件系统级错误的回调
             */
            checkPermission: function (options) {
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'checkPermission', {}, options.success, options.error);
            },
            //语音选人
            selectPeople: function (options) {
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'selectPeople', options.params || {}, options.success, function error(e) {
                    _handleSDKError(e, options.error);
                });
            },
            /**
             * 语音回复
             * @param selector 组件装载的容器 可以是id选择可以是class选择，如#id  .class
             * @param options 配置参数
             *          options.success 成功回调，最终的数据返回，{"text":"语音转出的最后文字","filepath":"file://语音文件在手机端的路径，用于播放和上传用，开发者可根据此参数是否不为空来判断是录音还是只是语音转文字"}
             *          options.error 失败回调
             */
            obtainSpeechReply: function (selector,options) {

                var micState = 0;//录音的动作状态，0：停止录音；1：开始录音
                var resultData;//返回的数据

                var speechReplyContainer = document.querySelector(selector);
                var domHeight = speechReplyContainer.offsetHeight;
                var recordinhHeight = domHeight-50;
                var divHeight = (recordinhHeight -144)/2;

                var htmlStr = getSpeechReplyHtml();
                speechReplyContainer.innerHTML = htmlStr;

                var speechInput = document.getElementById("cmpXiaozhiSpeechInput");//组件的容器
                var cmpXiaozhiCancelBtn = document.getElementById("cmpXiaozhiCancelBtn");
                var cmpXiaozhiFinishBtn = document.getElementById("cmpXiaozhiFinishBtn");

                cmpXiaozhiCancelBtn.addEventListener("tap",function () {
                    cmpXiaozhiFinishBtn.classList.add("active");
                    cancelSpeechReply();
                });
                cmpXiaozhiFinishBtn.addEventListener("tap",function () {
                    cmpXiaozhiFinishBtn.classList.remove("active");
                    options.success(resultData);
                    closeSpeechReply();
                });

                addMicEventListener();

                //显示界面
                speechInput.classList.add("cmp-active");
                speechInput.classList.add('right-go');

                /* 获取界面html*/
                function getSpeechReplyHtml() {
                    var resultHtml = ' <div id="cmpXiaozhiSpeechInput" class="cmp-popover cmp-popover-action cmp-popover-bottom cmp-xiaozhi-sdk-popover-bottom " style="height: '+domHeight+'px;">\n' +
                        '        <div class="cmp-popover-container cmp-xiaozhi-sdk-popover-container">\n' +
                        '            <ul class="cmp-xiaozhi-sdk-speech-nav flex cmp-list-unstyled">\n' +
                        '                <li class="item flex1">\n' +
                        '                    <div id="cmpXiaozhiCancelBtn" class="xiaozhi-nav-back cmp-icon see-icon-v5-common-arrow-back"></div>\n' +
                        '                </li>\n' +
                        '                <li class="item flex1">\n' +
                        '                    <div class="xiaozhi-nav-title">录音</div>\n' +
                        '                </li>\n' +
                        '                <li class="item flex1" >\n' +
                        '                    <div id="cmpXiaozhiFinishBtn" class="xiaozhi-nav-finish">完成</div>\n' +
                        '                </li>\n' +
                        '            </ul>\n' +
                        '            <div style="height: '+divHeight+'px"></div>\n' +
                        '            <div id="cmpXiaozhiSpeechInputCenter">\n' +
                        '                <div class="cmp-xiaozhi-sdk-speech-center">\n' +
                        '                    <div id="cmpXiaozSpeechRecoding" class="cmp-xiaozhi-sdk-speech-recoding">\n' +
                        '                        <div id="cmpXiaozhiTips" class="cmp-xiaozhi-sdk-speech-tips">点击开始录音</div>\n' +
                        '                        <div id="cmpXiaozhiMic" class="cmp-xiaozhi-sdk-speech-mic">\n' +
                        '                            <div class="outermost"></div>\n' +
                        '                            <div class="outer"></div>\n' +
                        '                            <div class="entry">\n' +
                        '                                <div class="see-icon-v5-common-m3-voice-fill"></div>\n' +
                        '                            </div>\n' +
                        '                        </div>\n' +
                        '                    </div>\n' +
                        '                    <div id="cmpXiaozSpeechFileSelector" class="cmp-xiaoz-sdk-speech-file">\n' +
                        '                    </div>\n' +
                        '                </div>\n' +
                        '            </div>\n' +
                        '        </div>\n' +
                        '    </div>';
                    return resultHtml;
                }

                /* 获取录音文件html*/
                function getSpeechFileHtml(duration) {
                    var resultHtml = '<div class="cmp-xiaoz-sdk-speech-item">\n' +
                        '        <div class="play-component flex flex-vc">\n' +
                        '            <div class="play-container flex flex-vc">\n' +
                        '                <div id="xiaozPlaySelector" class="play-icon">\n' +
                        '                    <span class="see-icon-play"></span>\n' +
                        '                </div>\n' +
                        '                <div id="xiaozPlayProgressSelector" class="flex4 play-progress-bar">\n' +
                        '                    <div id="xiaozPlayTagSelector" class="play-action-tag"></div>\n' +
                        '                </div>\n' +
                        '                <div id="xiaozPlayDurationSelector" class="flex1 play-display">'+duration+'</div>\n' +
                        '            </div>\n' +
                        '            <div id="xiaozDeleteFileSelector" class="play-close-bg" >\n' +
                        '                <div class="play-close see-icon-delete"></div>\n' +
                        '            </div>\n' +
                        '        </div>\n' +
                        '    </div>';
                    return resultHtml;
                }
                /* 显示录音界面*/
                function showRecordingView() {
                    var recording = document.getElementById("cmpXiaozSpeechRecoding");
                    recording.classList.remove('recoding-hide');
                    recording.classList.add('recoding-show');
                }
                function hideRecordingView() {
                    var recording = document.getElementById("cmpXiaozSpeechRecoding");
                    recording.classList.remove('recoding-show');
                    recording.classList.add('recoding-hide');
                    var tips = document.getElementById("cmpXiaozhiTips");//提示语
                    tips.classList.remove('interval-cut-down');

                }
                /* 显示录音文件*/
                function showSpeechFileView() {


                    var filepath = resultData.filepath;
                    var playFile;
                    var playActionTag;
                    var playProgressBar;
                    var display;
                    //获取录音长度
                    var voiceFile = new Media(filepath,function () {
                        var dur = parseInt(voiceFile.getDuration());//获取语音文件的时长
                        if (dur && dur > 0){
                            var duration = dur > 10 ? '00:'+dur :'00:0'+dur;
                            var playComponent = document.getElementById("cmpXiaozSpeechFileSelector");
                            playComponent.innerHTML = getSpeechFileHtml(duration);
                            cmpXiaozhiFinishBtn.classList.add("active");
                            playFile = document.getElementById("xiaozPlaySelector");
                            playActionTag = document.getElementById("xiaozPlayTagSelector");
                            playProgressBar = document.getElementById("xiaozPlayProgressSelector");
                            display = document.getElementById("xiaozPlayDurationSelector");

                            var deleteFile = document.getElementById("xiaozDeleteFileSelector");
                            micState = 0;
                            micStateChange(micState);

                            setTimeout(function () {
                                playComponent.classList.add('speech-file-transform-up');
                                setTimeout(function () {
                                    hideRecordingView();
                                },500);
                            },200);

                            cmpXiaozhiFinishBtn.classList.add("active");
                            deleteFile.addEventListener("tap",function () {
                                cmpXiaozhiFinishBtn.classList.remove("active");
                                if (playComponent) {
                                    playComponent.classList.remove('speech-file-transform-up');
                                    playComponent.classList.add('speech-file-transform-down');
                                }
                                setTimeout(function () {
                                    playComponent.innerHTML ='';
                                    showRecordingView();
                                    playComponent.classList.remove('speech-file-transform-down');
                                },500);
                            });

                            var playState = 0;//播放的状态，0：停止状态，1：播放状态
                            playFile.addEventListener("tap",function () {
                                var timer;
                                if(playState == 0){
                                    playState = 1;
                                    cmp.audio.playVoice({//播放语音文件
                                        url: filepath,
                                        initSuccess: function () {
                                            timer = initDisplay(dur,display,playProgressBar,playActionTag);
                                        },
                                        success: function (_url) {
                                            clearTime(timer,dur,display,playActionTag);
                                            playState = 0;
                                        }, error: function (e) {

                                        }
                                    });
                                }else {
                                    playState = 0;
                                    cmp.audio.stopVoice({//停止播放
                                        url:filepath,
                                        success:function () {
                                            clearTime(timer,dur,display,playActionTag);
                                            playState = 0;
                                        }
                                    })
                                }
                            });

                        }
                    },function (error) {
                    });
                    voiceFile.play();
                    voiceFile.stop();

                    //语音时长的显示转换
                    function formatNumberToTimeStr(num) {
                        if (num>10) {
                            return '00:'+num;
                        }
                        return "00:0"+num;
                    }
                    function initDisplay (num,display,playProgressBar,playActionTag) {
                        var  isAdd = (num == 0);
                        var barLength = playProgressBar.offsetWidth;
                        var oneSecondDistance = isAdd ? barLength: barLength/num;
                        function timer() {
                            if (num < 0) num = 0;
                            display.innerHTML =formatNumberToTimeStr(num);

                            if (isAdd) {
                                num++;
                            } else {
                                num--;
                            }
                            var distance = Math.floor(barLength - num*oneSecondDistance);
                            if(distance > barLength-5){
                                distance = barLength-5;
                            }
                            playActionTag.style.left = distance+"px";
                        }
                        setTimeout(function(){
                            timer();
                        },1000);

                        return window.setInterval(timer, 1000);
                    }

                    function clearTime(timer,num,display,playActionTag){
                        window.clearInterval(timer);
                        playActionTag.style.left = "0px";
                        display.innerHTML =formatNumberToTimeStr(num);
                    }
                }

                function addMicEventListener() {
                    var mic = document.getElementById("cmpXiaozhiMic");//麦克按钮
                    //点击录音按钮
                    mic.addEventListener("tap", function () {
                        if (micState == 0) {
                            micState = 1;
                        } else if (micState == 1) {
                            micState = 0;
                        }
                        micStateChange(micState);
                        if (micState == 0) {
                            stopSpeechReply();
                        } else {
                            beginSpeechReply();
                        }
                    });
                }
                var timeIntervalCount = 0;
                var timeInterval = null;
                /* 计时*/
                function startInterval() {
                    timeIntervalCount = 0;
                    timeInterval = window.setInterval(function () {
                        timeIntervalCount ++;
                        var tips = document.getElementById("cmpXiaozhiTips");//提示语
                        var timeStr = "点击结束 00:00";
                        var maxCount = 60;
                        if (timeIntervalCount >= maxCount){
                            //60s 自动停止了
                            micState = 0;
                            micStateChange(micState);
                            stopSpeechReply();
                            stopInterval();
                        }
                        else {
                            if (timeIntervalCount <4) {
                                timeStr = "点击结束 00:0"+timeIntervalCount;
                            }
                            else  {
                                var cutDown = maxCount- timeIntervalCount;
                                var secondStr = cutDown < 10 ? '0'+cutDown : ''+cutDown;
                                timeStr = "即将结束 00:"+secondStr;
                                tips.classList.add('interval-cut-down');
                            }
                        }
                        tips.innerHTML = timeStr;
                    }, 1000);
                }
                function stopInterval() {
                    // var tips = document.getElementById("cmpXiaozhiTips");//提示语
                    // tips.classList.remove('interval-cut-down');
                    // tips.innerHTML = "点击开始录音";
                    timeIntervalCount = 0;
                    if (timeInterval != null)  {
                        window.clearInterval(timeInterval);
                    }
                }
                //麦克样式变换
                function micStateChange(state) {
                    var mic = document.getElementById("cmpXiaozhiMic");//麦克按钮
                    var outermost = mic.getElementsByClassName("outermost")[0];//最外层
                    var outer = mic.getElementsByClassName("outer")[0];//外层
                    var tips = document.getElementById("cmpXiaozhiTips");//提示语
                    switch (state) {
                        case 0:
                            outermost.classList.remove("active");
                            outer.classList.remove("active");
                            tips.innerHTML = "点击开始录音";
                            stopInterval();
                            break;
                        case 1:
                            outermost.classList.add("active");
                            outer.classList.add("active");
                            tips.innerHTML = "点击结束 00:00";
                            startInterval();
                            break;
                    }
                }
                /*关闭语音回复界面*/
                function closeSpeechReply() {
                    var speechInput = document.getElementById("cmpXiaozhiSpeechInput");
                    if (speechInput != null) {
                        var parentInput = speechInput.parentNode;
                        if (parentInput != null) {
                            parentInput.removeChild(speechInput);
                        }
                        cmp.xiaozhi.exec('CMPSpeechPlugin', 'cancelSpeechReply', {}, function () {}, function () {});
                    }
                }
                /**
                 * 语音回复：开始
                 */
                function beginSpeechReply() {
                    //获取录音文件及转换的文本 返回值 {filepath:xxx,text:xxx}
                    cmp.xiaozhi.exec('CMPSpeechPlugin', 'obtainSpeechReplyFile', {}, function (result) {
                        resultData = result;
                        showSpeechFileView();
                    }, options.error);
                }
                /**
                 * 语音回复：停止
                 */
                function stopSpeechReply() {
                    cmp.xiaozhi.exec('CMPSpeechPlugin', 'stopSpeechReply', {}, function () {}, function () {});
                }
                /**
                 * 语音回复：取消
                 */
                function cancelSpeechReply() {
                    cmp.xiaozhi.exec('CMPSpeechPlugin', 'cancelSpeechReply', {}, function () {}, function () {});
                    closeSpeechReply();
                }
            },
            /**
             * 获取小致意图名称列表
             */
            getXiaozIntents: function (options) {
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'getXiaozIntents', {}, options.success, options.error);
            },
            /**
             * 打开小致界面，如全文检索点击小致图标
             * openFrom 来源，全文检索必填，其他可不填
             * success:成功回调，返回用户语音输入的命令文字(word)和命令key(key)
             * error:错误回调，包括code和message
             */
            openXiaoz: function (options) {
                var _options = cmp.extend({
                    openFrom:"common",
                    success:null,
                    error:null
                }, options);
                cmp.xiaozhi.exec('CMPSpeechPlugin', 'openXiaoz', {openFrom:_options.openFrom}, _options.success, _options.error);
            }
        }
    };

    /**
     * 处理sdk错误，处理打开sdk相关权限
     * @param e 错误对象
     * @param errorCallback 错误回调函数
     * @private
     */
    function _handleSDKError(e,errorCallback){
        var errorMsg = "";
        var errorCode = e.code;
        switch (errorCode){
            case 59001://无录音权限
                errorMsg = $.i18n("cmp.xiaozhi.sdk.speech.permissionTips");
                break;
            case 60001://无相机权限
                errorMsg = $.i18n("cmp.xiaozhi.sdk.faceDetect.permissionTips");
                break;
        }
        if(errorMsg){
            $.notification.confirm(errorMsg, function (index) {
                if (index == 0) {
                    return;
                } else if (index == 1) {
                    cordova.exec(
                        function () {
                        },
                        function () {
                        },
                        "CMPSettingPlugin",
                        "enterSetting",
                        []
                    );
                }
            }, "", [$.i18n("cmp.xiaozhi.sdk.cancel"), $.i18n("cmp.xiaozhi.sdk.toSet")]);//"取消","去设置"
        }else {
            errorCallback && errorCallback(e);
        }

    }
    $.xiaozhi = new sdk();

})(cmp);